DatabaseManager class

Manages the active database connection and builder.

Constructors

DatabaseManager(ConfigInterface _config)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schemaBuilder SchemaBuilder
Gets the current schema builder (for default connection).
no setter

Methods

close() Future<void>
Closes all active connections.
connection([String? name]) DatabaseConnection
Gets the current connection.
init() Future<String>
Initializes the default connection.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
table<T>(String tableName, {T modelFactory(Map<String, dynamic>)?, String? connectionName}) QueryBuilderInterface<T>
Gets a query builder for the given table.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited