BoolCast class
Cast attribute to/from boolean
Handles string and int to bool conversion automatically
Example:
Map<String, Type> get casts => {
'is_active': BoolCast,
'verified': BoolCast,
};
- Inheritance
-
- Object
- AttributeCaster<
bool> - BoolCast
Constructors
- BoolCast()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
get(
dynamic value) → bool? -
Convert database value to model property value
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
set(
bool? value) → dynamic -
Convert model property value to database value
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited