IntCast class
Cast attribute to/from integer
Handles string to int conversion automatically
Example:
Map<String, Type> get casts => {
'age': IntCast,
'count': IntCast,
};
- Inheritance
-
- Object
- AttributeCaster<
int> - IntCast
Constructors
- IntCast()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
get(
dynamic value) → int? -
Convert database value to model property value
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
set(
int? value) → dynamic -
Convert model property value to database value
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited