ModelDeleting<T> class

Event fired before a model is deleted.

Inheritance
Implemented types

Constructors

ModelDeleting(T model)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isPropagationStopped → bool
Checks if the event propagation has been stopped.
no setteroverride
model → T
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → DateTime
The time when the event occurred.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
stopPropagation() → void
Stops the event from being processed by further listeners.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited