ModelObserver<T extends KhademModel<T>> class abstract

Base class for model observers.

Constructors

ModelObserver()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

created(T model) → void
creating(T model) → dynamic
deleted(T model) → void
deleting(T model) → dynamic
forceDeleted(T model) → void
forceDeleting(T model) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
restored(T model) → void
restoring(T model) → dynamic
retrieved(T model) → void
retrieving(T model) → void
saved(T model) → void
saving(T model) → dynamic
toString() String
A string representation of this object.
inherited
updated(T model) → void
updating(T model) → dynamic

Operators

operator ==(Object other) bool
The equality operator.
inherited