ModelRetrieved<T> class

Event fired after a model is retrieved.

Inheritance

Constructors

ModelRetrieved(T model)

Properties

hashCode int
The hash code for this object.
no setterinherited
model → T
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
The time when the event occurred.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited