MorphedByMany<Related extends KhademModel<Related>, Parent> class

Inheritance

Constructors

MorphedByMany(QueryBuilderInterface<Related> query, Parent parent, Related relatedFactory(), String table, String foreignPivotKey, String relatedPivotKey, String parentKey, String relatedKey, String morphTypeField, String morphClass)

Properties

foreignPivotKey String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
inverse bool
finalinherited
morphClass String
finalinherited
morphTypeField String
finalinherited
parent → Parent
The parent model instance.
finalinherited
parentKey String
finalinherited
query QueryBuilderInterface<Related>
The query builder instance.
finalinherited
relatedFactory → Related Function()
The related model factory.
finalinherited
relatedKey String
finalinherited
relatedPivotKey String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
table String
finalinherited

Methods

addConstraints() → void
Set the base constraints on the relation query.
inherited
addEagerConstraints(List<KhademModel> models) → void
Set the constraints for an eager load of the relation.
inherited
getQuery() QueryBuilderInterface<Related>
Get the query builder for the relation.
inherited
getRelationExistenceQuery(QueryBuilderInterface<Related> query, QueryBuilderInterface<Parent> parentQuery, [List<String> columns = const ['*']]) QueryBuilderInterface<Related>
Add the constraints for a relationship count query.
inherited
getResults() Future<List<Related>>
Get the results of the relationship.
inherited
initRelation(List<KhademModel> models, String relation) List<KhademModel>
Initialize the relation on a set of models.
inherited
match(List<KhademModel> models, List<Related> results, String relation) List<KhademModel>
Match the eagerly loaded results to their parents.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBase() QueryBuilderInterface<Related>
Get the underlying query builder.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited