PaginatedResult<T> class

Constructors

PaginatedResult({required List<T> data, required int total, required int perPage, required int currentPage, required int lastPage})

Properties

currentPage → int
final
data → List<T>
final
hashCode → int
The hash code for this object.
no setterinherited
lastPage → int
final
perPage → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
total → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toJsonAsync() → Future<Map<String, dynamic>>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited