RelationDefinition<T extends KhademModel<T>> class

Constructors

RelationDefinition({required RelationType type, required String relatedTable, required String localKey, required String foreignKey, required T factory(), String? ownerKey, String? relatedKey, String? pivotTable, String? foreignPivotKey, String? relatedPivotKey, String? morphTypeField, String? morphIdField, String? throughTable, String? firstKey, String? secondKey, String? secondLocalKey, dynamic query(QueryBuilderInterface)?})

Properties

factory → T Function()
final
firstKey String?
final
foreignKey String
The foreign key of the parent model.
final
foreignPivotKey String?
final
hashCode int
The hash code for this object.
no setterinherited
localKey String
The local key of the parent model.
final
morphIdField String?
final
morphTypeField String?
final
ownerKey String?
The owner key of the related model (for BelongsTo).
final
pivotTable String?
final
query → dynamic Function(QueryBuilderInterface)?
final
relatedKey String?
The related key of the related model (for BelongsToMany).
final
relatedPivotKey String?
final
relatedTable String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondKey String?
final
secondLocalKey String?
final
throughTable String?
final
type RelationType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toRelation(KhademModel parent, String relationName) Relation<T, KhademModel>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited