RelationMeta class

Constructors

RelationMeta({required String key, bool paginate = false, int? page, int? perPage, List nested = const [], Function? query})

Properties

hashCode int
The hash code for this object.
no setterinherited
key String
final
nested List
final
page int?
final
paginate bool
final
perPage int?
final
query Function?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited