query property
An optional custom query function to modify the query for this relation.
Implementation
final Function(QueryBuilderInterface)? query;
An optional custom query function to modify the query for this relation.
final Function(QueryBuilderInterface)? query;