Grammar class abstract

Base class for database query grammars.

Responsible for compiling query components into SQL strings.

Implementers

Constructors

Grammar()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectComponents List<String>
The components that make up a select clause.
getter/setter pair

Methods

compileAggregate(Map<String, dynamic> query, Map<String, dynamic> aggregate) String
Compile an aggregate query (count, max, min, etc.).
compileDelete(Map<String, dynamic> query) String
Compile a delete statement into SQL.
compileFrom(String table) String
Compile the "from" portion of the query.
compileGroups(List<String> groups) String
Compile the "group by" portion of the query.
compileHavings(List<Map<String, dynamic>> havings) String
Compile the "having" portion of the query.
compileIncrement(Map<String, dynamic> query, String column, int amount) String
Compile an increment statement into SQL.
compileIncrementEach(Map<String, dynamic> query, Map<String, int> columns, Map<String, dynamic> extras) String
Compile an increment each statement.
compileInsert(Map<String, dynamic> query, Map<String, dynamic> values) String
Compile an insert statement into SQL.
compileInsertMany(Map<String, dynamic> query, List<Map<String, dynamic>> values) String
Compile an insert statement with multiple rows.
compileJoins(List<Map<String, dynamic>> joins) String
Compile the "join" portion of the query.
compileLimit(int limit) String
Compile the "limit" portion of the query.
compileOffset(int offset) String
Compile the "offset" portion of the query.
compileOrders(List<Map<String, dynamic>> orders) String
Compile the "order by" portion of the query.
compileSelect(Map<String, dynamic> query) String
Compile a select query into SQL.
compileUpdate(Map<String, dynamic> query, Map<String, dynamic> values) String
Compile an update statement into SQL.
compileUpsert(Map<String, dynamic> query, List<Map<String, dynamic>> values, List<String> uniqueBy, [List<String>? update]) String
Compile an upsert statement.
compileWheres(List<Map<String, dynamic>> wheres) String
Compile the "where" portion of the query.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
wrap(String value) String
Wrap a value in keyword identifiers.
wrapTable(String table) String
Wrap a table in keyword identifiers.

Operators

operator ==(Object other) bool
The equality operator.
inherited