MySQLGrammar class

MySQL specific grammar implementation.

Inheritance

Constructors

MySQLGrammar()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectComponents List<String>
The components that make up a select clause.
getter/setter pairinherited

Methods

compileAggregate(Map<String, dynamic> query, Map<String, dynamic> aggregate) String
Compile an aggregate query (count, max, min, etc.).
inherited
compileDelete(Map<String, dynamic> query) String
Compile a delete statement into SQL.
override
compileFrom(String table) String
Compile the "from" portion of the query.
inherited
compileGroups(List<String> groups) String
Compile the "group by" portion of the query.
inherited
compileHavings(List<Map<String, dynamic>> havings) String
Compile the "having" portion of the query.
inherited
compileIncrement(Map<String, dynamic> query, String column, int amount) String
Compile an increment statement into SQL.
override
compileIncrementEach(Map<String, dynamic> query, Map<String, int> columns, Map<String, dynamic> extras) String
Compile an increment each statement.
override
compileInsert(Map<String, dynamic> query, Map<String, dynamic> values) String
Compile an insert statement into SQL.
override
compileInsertMany(Map<String, dynamic> query, List<Map<String, dynamic>> values) String
Compile an insert statement with multiple rows.
override
compileJoins(List<Map<String, dynamic>> joins) String
Compile the "join" portion of the query.
inherited
compileLimit(int limit) String
Compile the "limit" portion of the query.
inherited
compileOffset(int offset) String
Compile the "offset" portion of the query.
inherited
compileOrders(List<Map<String, dynamic>> orders) String
Compile the "order by" portion of the query.
inherited
compileSelect(Map<String, dynamic> query) String
Compile a select query into SQL.
override
compileUnion(Map<String, dynamic> union) String
compileUnions(List<Map<String, dynamic>> unions) String
compileUpdate(Map<String, dynamic> query, Map<String, dynamic> values) String
Compile an update statement into SQL.
override
compileUpsert(Map<String, dynamic> query, List<Map<String, dynamic>> values, List<String> uniqueBy, [List<String>? update]) String
Compile an upsert statement.
override
compileWheres(List<Map<String, dynamic>> wheres) String
Compile the "where" portion of the query.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
wrap(String value) String
Wrap a value in keyword identifiers.
override
wrapTable(String table) String
Wrap a table in keyword identifiers.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited