onDelete method
Specifies the action to take when the foreign key is deleted.
Implementation
ColumnDefinition onDelete(String action) {
_onDeleteAction = action;
return this;
}
Specifies the action to take when the foreign key is deleted.
ColumnDefinition onDelete(String action) {
_onDeleteAction = action;
return this;
}