onUpdate method
Specifies the action to take when the foreign key is updated.
Implementation
ColumnDefinition onUpdate(String action) {
_onUpdateAction = action;
return this;
}
Specifies the action to take when the foreign key is updated.
ColumnDefinition onUpdate(String action) {
_onUpdateAction = action;
return this;
}