AllDevicesLogoutStrategy class

All devices logout strategy

This strategy invalidates all tokens for a user across all devices. Works for both JWT and Token drivers.

Implemented types

Constructors

AllDevicesLogoutStrategy(TokenService _tokenService)

Properties

description String
Gets a description of what this strategy does
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

invalidateTokens(TokenInvalidationContext context) Future<void>
Invalidates tokens according to the strategy
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited