AuthConfig class abstract
Configuration interface for authentication services
This interface defines the contract for accessing authentication configuration data. It allows for different configuration sources and provides a consistent interface for auth services.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAllProviderKeys(
) → List< String> - Gets all available provider keys
-
getDefaultGuard(
) → String - Gets the default guard name
-
getDefaultProvider(
) → String - Gets the default provider key
-
getDriver(
String driverName) → Map< String, dynamic> - Gets the driver configuration
-
getGuard(
String guardName) → Map< String, dynamic> - Gets the guard configuration
-
getOrDefault<
T> (String key, T defaultValue) → T - Gets a configuration value with a default fallback
-
getProvider(
String providerKey) → Map< String, dynamic> - Gets the authentication provider configuration
-
getProvidersForGuard(
String guardName) → List< Map< String, dynamic> > - Gets providers for a specific guard
-
hasGuard(
String guardName) → bool - Checks if a guard exists
-
hasProvider(
String providerKey) → bool - Checks if a provider exists
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited