getDriver abstract method

Map<String, dynamic> getDriver(
  1. String driverName
)

Gets the driver configuration

driverName The driver name to retrieve Returns the driver configuration or an empty map if not set

Implementation

Map<String, dynamic> getDriver(String driverName);