getProvidersForGuard abstract method

List<Map<String, dynamic>> getProvidersForGuard(
  1. String guardName
)

Gets providers for a specific guard

guardName The guard name to get providers for Returns a list of provider configurations for the guard

Implementation

List<Map<String, dynamic>> getProvidersForGuard(String guardName);