attempt method

Future<AuthResponse> attempt(
  1. Map<String, dynamic> credentials
)

Attempts to authenticate a user with the provided credentials

credentials A map containing authentication credentials Returns authentication result with user data and tokens Throws AuthException if authentication fails

Implementation

Future<AuthResponse> attempt(Map<String, dynamic> credentials) async {
  return _guardInstance.attempt(credentials);
}