logoutAllWithGuard method

Future<void> logoutAllWithGuard(
  1. String guardName,
  2. dynamic token
)

Logs out the current user from all devices with a specific guard

guardName The guard to use token The user ID to logout from all devices

Implementation

Future<void> logoutAllWithGuard(String guardName, dynamic token) async {
  final guard = _getOrCreateGuard(guardName);
  await guard.logoutAll(token);
}