AuthMiddlewareConfig class

Configuration for AuthMiddleware

Constructors

AuthMiddlewareConfig({required AuthType authType, AuthManager? authManager, String guard = 'api', String? realm, String? apiKeyHeader, Future<Authenticatable?> customAuthenticator(Request)?, List<String> roles = const [], List<String> permissions = const [], bool cacheUser = false, MiddlewarePriority priority = MiddlewarePriority.auth, String name = 'auth'})
const

Properties

apiKeyHeader → String?
final
authManager → AuthManager?
final
authType → AuthType
final
cacheUser → bool
final
customAuthenticator → Future<Authenticatable?> Function(Request)?
final
guard → String
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
permissions → List<String>
final
priority → MiddlewarePriority
final
realm → String?
final
roles → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({AuthType? authType, AuthManager? authManager, String? guard, String? realm, String? apiKeyHeader, Future<Authenticatable?> customAuthenticator(Request)?, List<String>? roles, List<String>? permissions, bool? cacheUser, MiddlewarePriority? priority, String? name}) → AuthMiddlewareConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited