getAuthPassword abstract method
Gets the password for the user
Returns the hashed password or null if not set
Implementation
String? getAuthPassword();
Gets the password for the user
Returns the hashed password or null if not set
String? getAuthPassword();