HashPasswordVerifier class

Hash helper implementation of PasswordVerifier

This class implements the PasswordVerifier interface using the Khadem HashHelper utility. It provides secure password verification and hashing operations.

Implemented types

Constructors

HashPasswordVerifier()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

hash(String password) Future<String>
Creates a combined hash code for a number of objects.
override
needsRehash(String hash) bool
Checks if a hash needs rehashing
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validatePasswordStrength(String password) Map<String, dynamic>
Validates password strength
verify(String password, String hash) Future<bool>
Verifies a password against its hash
override

Operators

operator ==(Object other) bool
The equality operator.
inherited