verify method

  1. @override
Future<bool> verify(
  1. String password,
  2. String hash
)
override

Verifies a password against its hash

password The plain text password hash The hashed password to verify against Returns true if password matches the hash

Implementation

@override
Future<bool> verify(String password, String hash) async {
  return HashHelper.verify(password, hash);
}