getProvidersForGuard method
Gets providers for a specific guard
guardName The guard name to get providers for
Returns a list of provider configurations for the guard
Implementation
@override
List<Map<String, dynamic>> getProvidersForGuard(String guardName) {
final config = _getAuthConfig();
final providers = config['providers'] as Map<String, dynamic>?;
if (providers == null) {
return [];
}
// With the new structure, all providers can work with any guard
// The guard determines the driver, provider provides model/table info
return providers.values
.map((provider) => provider as Map<String, dynamic>)
.toList();
}