PasswordVerifier class abstract

Password verification interface

This interface defines the contract for password verification in the authentication system. It allows for different hashing algorithms while maintaining consistency.

Implementers

Constructors

PasswordVerifier()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

hash(String password) Future<String>
Hashes a password
override
needsRehash(String hash) bool
Checks if a hash needs rehashing
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
verify(String password, String hash) Future<bool>
Verifies a password against its hash

Operators

operator ==(Object other) bool
The equality operator.
inherited