removeAttribute method
Removes an attribute from the request.
Implementation
void removeAttribute(String key) {
// Since RequestParams doesn't have a remove method, we set it to null
setAttribute(key, null);
}
Removes an attribute from the request.
void removeAttribute(String key) {
// Since RequestParams doesn't have a remove method, we set it to null
setAttribute(key, null);
}