SingleDeviceLogoutStrategy class
Single device logout strategy
This strategy invalidates the current session/device tokens. For JWT: Blacklists access token and removes associated refresh token For Token: Simply deletes the access token
- Implemented types
Constructors
- SingleDeviceLogoutStrategy(TokenService _tokenService)
Properties
- description → String
-
Gets a description of what this strategy does
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
invalidateTokens(
TokenInvalidationContext context) → Future< void> -
Invalidates tokens according to the strategy
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited