TokenInvalidationContext class

Context object containing data needed for token invalidation

Constructors

TokenInvalidationContext({required String guard, String? accessToken, String? refreshToken, dynamic userId, Map<String, dynamic>? tokenPayload, int? tokenExpiry, Map<String, dynamic>? metadata})
const
TokenInvalidationContext.fromTokens({required dynamic userId, required String guard, String? accessToken, String? refreshToken, Map<String, dynamic>? tokenPayload, int? tokenExpiry, Map<String, dynamic>? metadata})
Creates context from an access token and optional refresh token
factory

Properties

accessToken String?
The access token to invalidate
final
guard String
The guard/provider key
final
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>?
Any additional metadata
final
refreshToken String?
The refresh token to invalidate
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tokenExpiry int?
Token expiry timestamp (for JWT tokens)
final
tokenPayload Map<String, dynamic>?
Additional token payload (for JWT tokens)
final
userId → dynamic
The user ID associated with the tokens
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited