TokenInvalidationStrategy class abstract

Token invalidation strategy interface

This interface defines different strategies for invalidating tokens during logout operations. It follows the Strategy pattern to provide flexible logout behaviors.

Implementers

Constructors

TokenInvalidationStrategy()

Properties

description String
Gets a description of what this strategy does
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

invalidateTokens(TokenInvalidationContext context) Future<void>
Invalidates tokens according to the strategy
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited