TokenInvalidationStrategyFactory class
Factory for creating token invalidation strategies
This factory follows the Factory pattern to create appropriate logout strategies. Simplified to only include necessary strategies.
Constructors
- TokenInvalidationStrategyFactory(TokenService _tokenService)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createStrategy(
LogoutType logoutType) → TokenInvalidationStrategy - Creates a strategy based on the logout type
-
getAvailableStrategies(
) → Map< LogoutType, String> - Gets all available logout strategies
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited