findTokensBySession abstract method

Future<List<Map<String, dynamic>>> findTokensBySession(
  1. String sessionId, [
  2. String? guard,
  3. String? type
])

Finds tokens by session ID

sessionId The session ID to search for guard Optional guard name to filter by type Optional token type to filter by (e.g., 'refresh') Returns list of token data for the session

Implementation

Future<List<Map<String, dynamic>>> findTokensBySession(
  String sessionId, [
  String? guard,
  String? type,
]);