CliNaming class

Constructors

CliNaming()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

ensureSuffix(String name, String suffix) String
normalizePathInput(String input) String
splitFolderAndName(String input) → ({String folder, String name})
toPascalCase(String input) String
toSnakeCase(String input) String