pull abstract method

Future pull(
  1. String key
)

Retrieve an item from the cache and delete it.

  • Parameters:
    • key: The key of the item to retrieve and delete.
  • Returns: The value of the item, or null if not found.

Implementation

Future<dynamic> pull(String key);