getOrFail<T> abstract method
Returns the value of the key or throws an exception if not found.
Implementation
T getOrFail<T>(String key);
Returns the value of the key or throws an exception if not found.
T getOrFail<T>(String key);