set abstract method
Sets a configuration value for the specified key.
This can be used to override existing values or define new ones at runtime.
Example:
config.set('app.debug', true);
Implementation
void set(String key, dynamic value);
Sets a configuration value for the specified key.
This can be used to override existing values or define new ones at runtime.
Example:
config.set('app.debug', true);
void set(String key, dynamic value);