resolveAll<T> abstract method
Resolves and returns all instances of type T.
This is useful for multi-bindings where multiple factories are registered for T.
It collects all available instances based on registered bindings.
Returns a list of resolved instances of T.
Throws an exception if no bindings exist for T or if resolution fails.
Implementation
List<T> resolveAll<T>();