setMissingBindingHandler abstract method

void setMissingBindingHandler(
  1. void handler(
    1. Type type
    )
)

Sets a handler to be called when a service is not found.

This allows for lazy loading of service providers or dynamic binding.

Implementation

void setMissingBindingHandler(void Function(Type type) handler);