unbind<T> abstract method

void unbind<T>()

Removes the binding for type T.

This unbinds T from the container, including any contextual bindings. After unbinding, T can no longer be resolved until rebound.

Throws an exception if no binding exists for T.

Implementation

void unbind<T>();