getSchemaBuilder abstract method
Returns a schema builder for creating and modifying database structure.
Implementation
SchemaBuilder getSchemaBuilder();
Returns a schema builder for creating and modifying database structure.
SchemaBuilder getSchemaBuilder();