isConnected property
bool
get
isConnected
Checks if the connection is currently active and usable.
Implementation
bool get isConnected;
Checks if the connection is currently active and usable.
bool get isConnected;