Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispatch(Event event)
→ Future<void>
-
Dispatch an event and call the listeners.
-
forget(Type eventType)
→ void
-
Remove a set of listeners from the dispatcher.
-
listen<T extends Event>(dynamic listener)
→ void
-
Register an event listener with the dispatcher.
-
listenType(Type eventType, dynamic listener)
→ void
-
Register an event listener with the dispatcher by type.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
subscribe(dynamic subscriber)
→ void
-
Register an event subscriber with the dispatcher.
-
toString()
→ String
-
A string representation of this object.
inherited