emitGroup abstract method

Future<void> emitGroup(
  1. String groupName, [
  2. dynamic payload,
  3. bool queue = false
])

Emits all events within a named group.

This calls emit for each event in the group with the same parameters. Useful for triggering related events together.

  • groupName: The name of the group to emit.
  • payload: Optional data for all events.
  • queue: Queue the emissions.

Returns a Future that completes when all group events are emitted.

Example:

await events.emitGroup('user.lifecycle', userData);

Implementation

Future<void> emitGroup(
  String groupName, [
  dynamic payload,
  bool queue = false,
]);