offEvent abstract method
Removes all listeners for a specific event.
This clears the entire listener list for the event.
event: The event name to clear.
Example:
events.offEvent('user.created');
Implementation
void offEvent(String event);
Removes all listeners for a specific event.
This clears the entire listener list for the event.
event: The event name to clear.Example:
events.offEvent('user.created');
void offEvent(String event);