ExceptionHandlerContract class abstract interface

Contract for handling exceptions in the application.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

handle(Object error, [StackTrace? stackTrace]) Future<ErrorResult>
Handle an exception and return a standardized error result.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register<T extends Object>(Future<ErrorResult> handler(T error, StackTrace? stackTrace)) → void
Register a custom handler for a specific exception type.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited