handle abstract method
Handle an exception and return a standardized error result.
Implementation
Future<ErrorResult> handle(
Object error, [
StackTrace? stackTrace,
]);
Handle an exception and return a standardized error result.
Future<ErrorResult> handle(
Object error, [
StackTrace? stackTrace,
]);