FailedJob class

Represents a failed job stored in the Dead Letter Queue

Constructors

FailedJob({required String id, required String jobType, required Map<String, dynamic> payload, required String error, required DateTime failedAt, required int attempts, String? stackTrace, Map<String, dynamic>? metadata})
FailedJob.fromJson(Map<String, dynamic> json)
factory

Properties

attempts int
final
error String
final
failedAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
jobType String
final
metadata Map<String, dynamic>
final
payload Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited