ICacheStatisticsManager class abstract

Interface for cache statistics management. Defines the contract for tracking and reporting cache performance metrics.

Implementers

Constructors

ICacheStatisticsManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAllStats() Map<String, CacheStats>
Gets statistics for all drivers.
getStats(String driverName) CacheStats
Gets statistics for a specific driver.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetAllStats() → void
Resets statistics for all drivers.
resetStats(String driverName) → void
Resets statistics for a specific driver.
toString() String
A string representation of this object.
inherited
updateStats(String driverName, {required bool hit, required String operation, bool error = false}) → void
Updates statistics for a cache operation.

Operators

operator ==(Object other) bool
The equality operator.
inherited