ICacheTagManager class abstract

Interface for cache tag management. Defines the contract for managing cache tags and group invalidation.

Implementers

Constructors

ICacheTagManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearAllTags() → void
Clears all tag associations.
forgetByTag(String tag) Future<void>
Removes all cache items associated with the given tag.
getAllTags() Set<String>
Gets all registered tags.
getKeysForTag(String tag) Set<String>
Gets all keys associated with a tag.
getTagsForKey(String key) Set<String>
Gets all tags for a key.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeTagsForKey(String key) → void
Removes all tags for a key.
tag(String key, List<String> tags) Future<void>
Tags a cache item with one or more tags.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited