removeDriver abstract method
Removes a driver from the registry. Throws QueueException if the driver is not registered or is the default driver.
Implementation
void removeDriver(String name);
Removes a driver from the registry. Throws QueueException if the driver is not registered or is the default driver.
void removeDriver(String name);