KhademCommand class abstract
Base class for all CLI commands in Khadem.
- Inheritance
-
- Object
- Command<
void> - KhademCommand
- Implementers
- BuildCommand
- CommandsCommand
- MakeCommandCommand
- MakeControllerCommand
- MakeEventCommand
- MakeExceptionCommand
- MakeJobCommand
- MakeListenerCommand
- MakeMailCommand
- MakeMiddlewareCommand
- MakeMigrationCommand
- MakeModelCommand
- MakeObserverCommand
- MakeProviderCommand
- MakeRequestCommand
- MakeRuleCommand
- MakeSeederCommand
- MakeTestCommand
- MakeViewCommand
- NewCommand
- ServeCommand
- StorageLinkCommand
- VersionCommand
Constructors
- KhademCommand({required LoggerContract logger})
Properties
-
aliases
→ List<
String> -
Alternate names for this command.
no setterinherited
- argParser → ArgParser
-
The argument parser for this command.
no setterinherited
- argResults → ArgResults?
-
The parsed argument results for this command.
no setterinherited
- category → String
-
The command's category.
no setterinherited
- description → String
-
A description of this command, included in
usage.no setterinherited - exitCode ↔ int
-
getter/setter pair
- globalResults → ArgResults?
-
The parsed global argument results.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
Whether or not this command should be hidden from help listings.
no setterinherited
- invocation → String
-
A single-line template for how to invoke this command (e.g.
"pub getpackage").no setterinherited - logger → LoggerContract
-
final
- name → String
-
The name of this command.
no setterinherited
-
parent
→ Command<
void> ? -
The command's parent command, if this is a subcommand.
no setterinherited
-
runner
→ CommandRunner<
void> ? -
The command runner for this command.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subcommands
→ Map<
String, Command< void> > -
An unmodifiable view of all sublevel commands of this command.
no setterinherited
-
suggestionAliases
→ List<
String> -
Alternate non-functional names for this command.
no setterinherited
- summary → String
-
A short description of this command, included in
parent'sCommandRunner.usage.no setterinherited - takesArguments → bool
-
Whether or not this command takes positional arguments in addition to
options.
no setterinherited
- usage → String
-
Generates a string displaying usage information for this command.
no setterinherited
-
An optional footer for
usage.no setterinherited
Methods
-
addSubcommand(
Command< void> command) → void -
Adds
Commandas a subcommand of this.inherited -
fail(
String message, {int code = 1}) → void -
handle(
List< String> args) → Future<void> - Called automatically before executing the command. You can override to do pre-validation or setup.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
printUsage(
) → void -
Prints the usage information for this command.
inherited
-
run(
) → Future< void> -
Runs this command.
override
-
succeed(
[int code = 0]) → void -
toString(
) → String -
A string representation of this object.
inherited
-
usageException(
String message) → Never -
Throws a
UsageExceptionwithmessage.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited