Listener<T extends Event> class abstract

Base class for event listeners.

Listeners are responsible for handling specific events.

T is the type of event this listener handles.

Constructors

Listener()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

failed(T event, Object error, StackTrace stackTrace) FutureOr<void>
Handle the event failure.
handle(T event) FutureOr<void>
Handle the event.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited