LogLevel enum

Represents different levels of logging.

Inheritance
Available extensions

Values

debug → const LogLevel

Detailed information for debugging purposes

info → const LogLevel

General information about system operation

warning → const LogLevel

Warning messages for potentially harmful situations

error → const LogLevel

Error messages for serious problems

critical → const LogLevel

Critical messages for fatal errors that need immediate attention

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String
Gets the string representation of the log level.
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
nameUpper String
Gets the uppercase string representation of the log level.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
Gets the integer value of the log level for comparison.
no setter

Methods

isAtLeast(LogLevel other) bool
Checks if this log level is at least as severe as the given level. Returns true if this level should be logged when the minimum level is other.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromString(String value) LogLevel
Parses a string into a LogLevel

Constants

values → const List<LogLevel>
A constant List of the values in this enum, in order of their declaration.