isAtLeast method

bool isAtLeast(
  1. LogLevel other
)

Checks if this log level is at least as severe as the given level. Returns true if this level should be logged when the minimum level is other.

Implementation

bool isAtLeast(LogLevel other) {
  return value >= other.value;
}