nameUpper property
String
get
nameUpper
Gets the uppercase string representation of the log level.
Implementation
String get nameUpper {
return name.toUpperCase();
}
Gets the uppercase string representation of the log level.
String get nameUpper {
return name.toUpperCase();
}