whereAny abstract method
Matches ANY of the columns with the given operator and value
Implementation
QueryBuilderInterface<T> whereAny(
List<String> columns,
String operator,
dynamic value,
);
Matches ANY of the columns with the given operator and value
QueryBuilderInterface<T> whereAny(
List<String> columns,
String operator,
dynamic value,
);