QueueDriver class abstract interface

Defines the core interface for any queue driver implementation.

A queue driver is responsible for pushing jobs into a queue and processing them. Implement this interface for custom drivers like Redis, Database, In-Memory, etc.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process() Future<void>
Starts processing queued jobs.
push(QueueJob job, {Duration? delay}) Future<void>
Pushes a QueueJob to the queue with optional delay.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited