process abstract method
Starts processing queued jobs.
This method is typically used in a worker loop.
Example:
await queueDriver.process(); // start the worker
Implementation
Future<void> process();
Starts processing queued jobs.
This method is typically used in a worker loop.
Example:
await queueDriver.process(); // start the worker
Future<void> process();