QueueMetricsContract class abstract interface

Interface for queue metrics collection

Properties

averageProcessingTime Duration
Get average processing time
no setter
failureRate double
Get failure rate (0.0 to 1.0)
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
successRate double
Get success rate (0.0 to 1.0)
no setter
throughput double
Get throughput (jobs per second)
no setter

Methods

jobCompleted(String jobType, Duration processingTime) → void
Record job completed
jobFailed(String jobType) → void
Record job failed
jobQueued(String jobType) → void
Record job queued
jobRetried(String jobType) → void
Record job retried
jobStarted() → void
Record job started
jobTimedOut(String jobType) → void
Record job timed out
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recordQueueDepth(int depth) → void
Record queue depth snapshot
reset() → void
Reset all metrics
toJson() Map<String, dynamic>
Export metrics as JSON
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited