QueueMiddleware class abstract
Middleware interface for queue jobs
Constructors
Properties
Methods
-
handle(
QueueJobContext context, Next next) → Future< void> - Handle the job context Call next() to continue to the next middleware or job execution
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited