handle abstract method
Handle the job context Call next() to continue to the next middleware or job execution
Implementation
Future<void> handle(QueueJobContext context, Next next);
Handle the job context Call next() to continue to the next middleware or job execution
Future<void> handle(QueueJobContext context, Next next);