QueueMonitor class abstract

Interface for queue monitoring and metrics collection.

Constructors

QueueMonitor()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getMetrics() QueueMetrics
Gets current queue statistics.
jobCompleted(QueueJob job, Duration processingTime) → void
Records that a job has completed successfully.
jobFailed(QueueJob job, dynamic error, Duration processingTime) → void
Records that a job has failed.
jobQueued(QueueJob job) → void
Records that a job has been queued.
jobRetried(QueueJob job, int attempt) → void
Records that a job is being retried.
jobStarted(QueueJob job) → void
Records that a job has started processing.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
Resets all metrics.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited