RouteGroupContract class abstract

Contract that defines route group behavior such as prefix and attached middleware.

Constructors

RouteGroupContract()

Properties

hashCode int
The hash code for this object.
no setterinherited
middleware List<Middleware>
List of middleware to apply to all routes in the group.
no setter
prefix String
Common prefix for all routes in the group.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited