middleware property
List<Middleware>
get
middleware
List of middleware to apply to all routes in the group.
Implementation
List<Middleware> get middleware;
List of middleware to apply to all routes in the group.
List<Middleware> get middleware;