ScheduledJob class abstract

Represents a job that can be scheduled for execution at a specific time or interval.

Implement this abstract class to define your own scheduled jobs.

Example:

class CleanupJob extends ScheduledJob {
  @override
  String get name => 'cleanup_job';

  @override
  Future<void> execute() async {
    // your logic here
  }
}
Implementers

Constructors

ScheduledJob()

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Unique name of the job (used for identification and control).
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute() Future<void>
Main logic that should be executed when the job runs.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited