SchedulerEngineContract class abstract
Contract for the Scheduler Engine
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
activeTasks(
) → List< String> - Get a list of active task names
-
add(
ScheduledTask task) → void - Add a new scheduled task
-
getStats(
) → Map< String, TaskStats> - Get task statistics
-
isRunning(
String name) → bool - Check if a task is currently running
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pause(
String name) → void - Pause a specific task
-
resume(
String name) → void - Resume a paused task
-
stop(
String name) → void - Stop a specific task by name
-
stopAll(
) → void - Stop all running tasks
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited