SchemaBuilder class abstract interface

Interface for building or modifying database schemas.

This builder is used in migrations to define table structure.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
queries List<String>
Returns the raw list of SQL queries generated by the builder.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(String tableName, void callback(Blueprint table)) → void
Creates a new table with the given tableName and callback.
createIfNotExists(String tableName, void callback(Blueprint table)) → void
Creates the table if it does not exist already.
drop(String tableName) → void
Drops the specified table.
dropIfExists(String tableName) → void
Drops the table only if it exists.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited