connection property
String?
get
connection
The name of the connection the job should be sent to.
Implementation
String? get connection => null;
The name of the connection the job should be sent to.
String? get connection => null;