stopPropagation method
void
stopPropagation()
Stops the event from being processed by further listeners.
Implementation
void stopPropagation() {
_isPropagationStopped = true;
}
Stops the event from being processed by further listeners.
void stopPropagation() {
_isPropagationStopped = true;
}