Subscriber class abstract

Interface for event subscribers.

Subscribers allow you to group multiple event listeners within a single class.

Constructors

Subscriber()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subscribe(Dispatcher dispatcher) → void
Subscribe to events.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited