forever method
Stores a value in the cache forever using the default driver.
The item will remain in the cache indefinitely until manually removed or the cache is cleared.
Throws CacheException if the key is empty or if the operation fails.
Implementation
@override
Future<void> forever(String key, dynamic value) async {
await put(key, value, const Duration(days: 365 * 10));
}