loadFromConfig method

void loadFromConfig(
  1. ConfigInterface config
)

Loads cache configuration from the application's config.

This method reads cache settings from the configuration and automatically registers the appropriate cache drivers based on the configuration.

The configuration should have the following structure:

cache:
  default: memory
  drivers:
    memory:
      driver: memory
    file:
      driver: file
      path: ./storage/cache

Throws CacheException if the configuration is invalid or if a driver cannot be initialized.

Implementation

void loadFromConfig(ConfigInterface config) {
  _configLoader.loadFromConfig(config, _driverRegistry);
}