setDefaultDriver method

void setDefaultDriver(
  1. String name
)

Sets the default cache driver.

All cache operations will use this driver unless a specific driver is requested using the driver method.

Throws CacheException if the driver is not registered.

Implementation

void setDefaultDriver(String name) {
  _validator.validateDriverName(name);
  _driverRegistry.setDefaultDriver(name);
}