CacheStatisticsManager class

Implementation of cache statistics manager. Manages cache performance metrics and statistics tracking.

Implemented types

Constructors

CacheStatisticsManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAllStats() Map<String, CacheStats>
Gets statistics for all drivers.
override
getStats(String driverName) CacheStats
Gets statistics for a specific driver.
override
initializeDriverStats(String driverName) → void
Initializes statistics for a driver.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetAllStats() → void
Resets statistics for all drivers.
override
resetStats(String driverName) → void
Resets statistics for a specific driver.
override
toString() String
A string representation of this object.
inherited
updateStats(String driverName, {required bool hit, required String operation, bool error = false}) → void
Updates statistics for a cache operation.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited