dispose method

void dispose()

Disposes of the cache driver and cleans up resources.

Cancels the cleanup timer and clears all cache entries. Call this method when the cache driver is no longer needed to prevent memory leaks from the periodic timer.

Implementation

void dispose() {
  _cleanupTimer?.cancel();
  _store.clear();
}