itemCount property
int
get
itemCount
Gets the current number of items in the cache.
Implementation
int get itemCount => _store.length;
Gets the current number of items in the cache.
int get itemCount => _store.length;