events library

Classes

CallQueuedListener
A queue job that executes a specific listener for an event.
EventDispatcher
The default event dispatcher implementation.
EventMethod
A single event handler method.
EventRegistration
Event registration information with priority and one-time execution flag.
EventSystem
A concrete implementation of EventSystemInterface.

Functions

registerSubscribers(List<EventSubscriberInterface> subscribers, [EventSystemInterface? eventSystem]) → void
Utility for registering event subscribers with the global event system.