handler property
The handler function that will be called when the event is fired.
Implementation
final Future<void> Function(dynamic payload) handler;
The handler function that will be called when the event is fired.
final Future<void> Function(dynamic payload) handler;