once property

bool once
final

Whether the handler should be called only once.

If once is true, the handler will be executed only once and then removed from the event listeners.

Implementation

final bool once;