priority property

EventPriority priority
final

The priority of the handler.

The priority determines the order in which the event handlers are executed. The handlers with the highest priority are executed first.

Implementation

final EventPriority priority;