EventRegistration class
Event registration information with priority and one-time execution flag.
Used internally by EventSystem to store event listeners.
- Annotations
-
- @Deprecated('Internal use only for deprecated EventSystem')
Constructors
- EventRegistration(EventListener listener, EventPriority priority, bool once)
- Creates a new event registration.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- listener → EventListener
-
The event listener.
final
- once → bool
-
Whether the event listener should only be called once.
final
- priority → EventPriority
-
The priority of the event listener.
final
- removed ↔ bool
-
Whether the listener has been removed.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
compareTo(
EventRegistration other) → int - Compares the priority of this registration with another.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited