removed property
Whether the listener has been removed.
Used by EventSystem to track whether the listener has been removed.
Implementation
bool removed = false;
Whether the listener has been removed.
Used by EventSystem to track whether the listener has been removed.
bool removed = false;