removeFromGroup method
Removes an event from group groupName.
Removes the specified event from the group. If the group becomes empty after removal, the entire group is removed from the system.
groupName - The name of the group to remove the event from
event - The event name to remove from the group
Implementation
@override
void removeFromGroup(String groupName, String event) {
_eventGroups[groupName]?.remove(event);
if (_eventGroups[groupName]?.isEmpty ?? false) {
_eventGroups.remove(groupName);
}
}