exception library

Classes

ErrorResult
Represents a standardized error result.
ExceptionHandler
Handles exceptions raised in the application and returns standardized error results.
ExceptionReporter
Central place to log or report exceptions to a third-party service.