addGlobalContext static method
Add custom context that will be included in all future reports
Implementation
static void addGlobalContext(String key, dynamic value) {
_globalContext[key] = value;
}
Add custom context that will be included in all future reports
static void addGlobalContext(String key, dynamic value) {
_globalContext[key] = value;
}