setFallbackLocale method
Sets the fallback locale for missing translations.
When a translation is not found in the current locale, this locale will be used as a fallback.
locale: The fallback locale code.
Implementation
@override
void setFallbackLocale(String locale) {
_fallbackLocale = locale;
}