CallbackLogHandler class

A log handler that delegates logging to a callback function. Useful for integrating with external services or testing.

Implemented types

Constructors

CallbackLogHandler(void _callback(LogLevel level, String message, Map<String, dynamic>? context, StackTrace? stackTrace), {LogLevel minimumLevel = LogLevel.debug})

Properties

hashCode int
The hash code for this object.
no setterinherited
minimumLevel LogLevel
The minimum log level this handler should process.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
override
log(LogLevel level, String message, {Map<String, dynamic>? context, StackTrace? stackTrace}) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited