FileLogHandler class

File-based log handler with non-blocking I/O and buffering.

Implemented types

Constructors

FileLogHandler({required String filePath, int maxFileSizeBytes = 5 * 1024 * 1024, int maxBackupCount = 5, bool rotateOnSize = true, bool rotateDaily = false, bool formatJson = true, LogLevel minimumLevel = LogLevel.debug})

Properties

hashCode int
The hash code for this object.
no setterinherited
minimumLevel LogLevel
The minimum log level this handler should process.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
override
log(LogLevel level, String message, {Map<String, dynamic>? context, StackTrace? stackTrace}) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited