LogEntry class

Represents a single log entry.

Constructors

LogEntry({required LogLevel level, required String message, required DateTime timestamp, Map<String, dynamic>? context, StackTrace? stackTrace})

Properties

context → Map<String, dynamic>?
final
hashCode → int
The hash code for this object.
no setterinherited
level → LogLevel
final
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace?
final
timestamp → DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited