DriverConfig class

Configuration for queue drivers

Constructors

DriverConfig({required String name, bool trackMetrics = true, bool useDLQ = true, bool useMiddleware = true, Duration? defaultJobTimeout, int maxRetries = 3, Duration retryDelay = const Duration(seconds: 30), Map<String, dynamic> driverSpecificConfig = const {}})
const

Properties

defaultJobTimeout Duration?
final
driverSpecificConfig Map<String, dynamic>
final
hashCode int
The hash code for this object.
no setterinherited
maxRetries int
final
name String
final
retryDelay Duration
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trackMetrics bool
final
useDLQ bool
final
useMiddleware bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited