FailedJobHandler class
Handler for managing failed jobs and retry logic
- Implemented types
Constructors
Properties
- dlq → DeadLetterQueue
-
Get the DLQ instance
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
exportToJson(
{int? limit}) → Future< String> -
Export failed jobs to JSON
override
-
getReport(
) → Future< Map< String, dynamic> > -
Get failed job report
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
prune(
{Duration? olderThan}) → Future< int> -
Prune old failed jobs
override
-
recordFailure(
{required String id, required String jobType, required Map< String, dynamic> payload, required dynamic error, required int attempts, StackTrace? stackTrace, Map<String, dynamic> ? metadata}) → Future<void> -
Record a job failure
override
-
retry(
String id) → Future< FailedJob?> -
Retry a failed job (returns the job for re-dispatch)
override
-
retryByType(
String jobType) → Future< List< FailedJob> > -
Retry all failed jobs of a specific type
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited