InMemoryDeadLetterQueue class

In-memory implementation of Dead Letter Queue

Implemented types

Constructors

InMemoryDeadLetterQueue()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() Future<void>
Clear all failed jobs
override
count() Future<int>
Get the total count of failed jobs
override
get(String id) Future<FailedJob?>
Retrieve a failed job by ID
override
getAll({int? limit, int? offset}) Future<List<FailedJob>>
Get all failed jobs
override
getByDateRange(DateTime start, DateTime end) Future<List<FailedJob>>
Get failed jobs within a date range
override
getByType(String jobType, {int? limit}) Future<List<FailedJob>>
Get failed jobs filtered by type
override
getStats() Future<Map<String, dynamic>>
Get failed job statistics
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String id) Future<void>
Remove a failed job from the DLQ
override
store(FailedJob job) Future<void>
Store a failed job in the DLQ
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited