JobContext class

Job context with metadata

Constructors

JobContext({required String id, required QueueJob job, required DateTime queuedAt, DateTime? scheduledFor, int attempts = 0, JobStatus status = JobStatus.pending, Map<String, dynamic>? metadata})

Properties

attempts int
getter/setter pair
error ↔ dynamic
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
final
isReady bool
no setter
job QueueJob
final
metadata Map<String, dynamic>
final
processingTime Duration
no setter
queuedAt DateTime
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheduledFor DateTime?
final
shouldRetry bool
no setter
stackTrace StackTrace?
getter/setter pair
status JobStatus
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited