JobPriority enum
Job priority levels
Values
- low → const JobPriority
-
const JobPriority(0) - normal → const JobPriority
-
const JobPriority(1) - high → const JobPriority
-
const JobPriority(2) - critical → const JobPriority
-
const JobPriority(3)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
isHigherThan(
JobPriority other) → bool - Compare priorities
-
isLowerThan(
JobPriority other) → bool - Compare priorities
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
JobPriority> - A constant List of the values in this enum, in order of their declaration.