PrioritizedJob class

Represents a job with priority and metadata

Implemented types

Constructors

PrioritizedJob({required QueueJob job, required JobPriority priority, required String id})

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
job QueueJob
final
priority JobPriority
final
queuedAt DateTime
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

compareTo(PrioritizedJob other) int
Compares this object to another object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited