PriorityQueueMetrics class

Priority queue statistics and monitoring

Constructors

PriorityQueueMetrics()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

averageProcessingTime(JobPriority priority) Duration
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recordJobFailed(JobPriority priority) → void
recordJobProcessed(JobPriority priority, Duration processingTime) → void
reset() → void
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited