QueueConfigLoader class
Implementation of queue configuration loader. Handles loading queue configuration and initializing drivers.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createDriverFromConfig(
String driverType, Map< String, dynamic> settings) → QueueDriver -
Creates a queue driver instance from configuration.
Throws QueueException if driver type is unknown or configuration is invalid.
override
-
loadFromConfig(
ConfigInterface config, IQueueDriverRegistry registry) → void -
Loads queue configuration and registers drivers.
Throws QueueException if configuration is invalid.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited