removeDriver method
Removes a driver from the registry. Throws QueueException if the driver is not registered or is the default driver.
Implementation
@override
void removeDriver(String name) {
unregister(name);
}
Removes a driver from the registry. Throws QueueException if the driver is not registered or is the default driver.
@override
void removeDriver(String name) {
unregister(name);
}