QueueWorkerPool class

Worker pool for concurrent job processing

Constructors

QueueWorkerPool({required QueueDriver driver, int workerCount = 4, QueueWorkerConfig? config})

Properties

hashCode int
The hash code for this object.
no setterinherited
isRunning bool
Check if pool is running
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
workerCount int
Get worker count
no setter

Methods

getStats() Map<String, dynamic>
Get pool statistics
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scale(int newWorkerCount) Future<void>
Scale the worker pool (add or remove workers)
start() Future<void>
Start the worker pool
stop({bool graceful = true}) Future<void>
Stop the worker pool
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited