RetryMiddleware class

Retry middleware

Implemented types

Constructors

RetryMiddleware({int maxAttempts = 3, Duration delay = const Duration(seconds: 1), bool shouldRetry(dynamic error)?})

Properties

delay Duration
final
hashCode int
The hash code for this object.
no setterinherited
maxAttempts int
final
name String
Get middleware name for debugging
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shouldRetry bool Function(dynamic error)?
final

Methods

handle(QueueJobContext context, Next next) Future<void>
Handle the job context Call next() to continue to the next middleware or job execution
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited