ServiceProviderBootloader class

Handles the booting process of service providers.

Properties

hashCode int
The hash code for this object.
no setterinherited
isBooted bool
Returns whether all providers have been booted.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bootAll(List<ServiceProvider> providers) Future<void>
Boots all providers and marks as booted.
bootDeferred(List<ServiceProvider> providers) Future<void>
Boots only deferred providers.
bootNonDeferred(List<ServiceProvider> providers) Future<void>
Boots only non-deferred providers.
bootProvider(ServiceProvider provider) Future<void>
Boots a single provider.
bootProviders(List<ServiceProvider> providers) Future<void>
Boots multiple providers sequentially.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
Resets the boot state.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited