ServiceProviderManager class
Manages lifecycle of all service providers (registration + boot). Uses modular components for better maintainability and separation of concerns.
Constructors
- ServiceProviderManager(ContainerInterface container)
Properties
-
allProviders
→ List<
ServiceProvider> -
Returns the list of all providers.
no setter
- areAllValid → bool
-
Checks if all providers are valid.
no setter
-
deferredProviders
→ List<
ServiceProvider> -
Gets deferred providers.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isBooted → bool
-
Checks if all providers have been booted.
no setter
-
nonDeferredProviders
→ List<
ServiceProvider> -
Gets non-deferred providers.
no setter
- providerCount → int
-
Gets the count of registered providers.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
bootAll(
) → Future< void> -
Boot all registered providers by calling their
boot()method. -
bootDeferred(
) → Future< void> - Boot only deferred providers.
-
bootNonDeferred(
) → Future< void> - Boot only non-deferred providers.
-
clear(
) → void - Clears all registered providers and resets boot state.
-
getProvidersByType<
T extends ServiceProvider> () → List< T> - Gets providers by type.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
ServiceProvider provider) → void -
Register a single provider and call
register(). -
registerAll(
List< ServiceProvider> providers) → void - Register multiple providers.
-
toString(
) → String -
A string representation of this object.
inherited
-
validateProviders(
) → List< String> - Validates all registered providers.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited