ServiceProviderValidator class

Handles validation of service providers.

Constructors

ServiceProviderValidator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

areAllValid(List<ServiceProvider> providers) bool
Checks if all providers in a list are valid.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validateDependencies(List<ServiceProvider> providers) List<String>
Validates provider dependencies (placeholder for future implementation).
validateProvider(ServiceProvider provider) bool
Validates a single provider.
validateProviders(List<ServiceProvider> providers) List<String>
Validates multiple providers.

Operators

operator ==(Object other) bool
The equality operator.
inherited