add method
Adds or updates a value in the request body.
Implementation
void add(String key, dynamic value) {
_bodyParser.add(key, value);
}
Adds or updates a value in the request body.
void add(String key, dynamic value) {
_bodyParser.add(key, value);
}