RequestValidator class

Handles validation of request data against specified rules.

Constructors

RequestValidator(BodyParser _bodyParser)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validateBody(Map<String, dynamic> rules, {Map<String, String>? messages}) Future<Map<String, dynamic>>
Validates the request body input against the given rules.
validateData(Map<String, dynamic> data, Map<String, dynamic> rules) Future<Map<String, dynamic>>
Validates specific input data against rules.

Operators

operator ==(Object other) bool
The equality operator.
inherited