sendChunked method
Sends a chunked response with manual control over chunks.
Implementation
void sendChunked(String data) {
if (_sent) return;
_response.add(_safeUtf8Encode(data));
// Don't close - allow more chunks
}
Sends a chunked response with manual control over chunks.
void sendChunked(String data) {
if (_sent) return;
_response.add(_safeUtf8Encode(data));
// Don't close - allow more chunks
}