isClientError property
bool
get
isClientError
Checks if the status code indicates client error (4xx).
Implementation
bool get isClientError => statusCode >= 400 && statusCode < 500;
Checks if the status code indicates client error (4xx).
bool get isClientError => statusCode >= 400 && statusCode < 500;