isServerError property
bool
get
isServerError
Checks if the status code indicates server error (5xx).
Implementation
bool get isServerError => statusCode >= 500 && statusCode < 600;
Checks if the status code indicates server error (5xx).
bool get isServerError => statusCode >= 500 && statusCode < 600;