hasMatch property
bool
get
hasMatch
Whether a route has been matched for this request
Implementation
bool get hasMatch => _matchedRoute != null;
Whether a route has been matched for this request
bool get hasMatch => _matchedRoute != null;