ServerLifecycle class

Constructors

ServerLifecycle(Router _router, ServerMiddleware _middleware, ServerStatic _static)

Properties

autoCompress bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
idleTimeout Duration
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reload() Future<void>
start({int port = 8080, String? host}) Future<void>
stop() Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited