ServerStaticHandler class

Responsible for serving static files from a given directory.

Constructors

ServerStaticHandler(String directory)

Properties

directory String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
tryServe(Request req, Response res) Future<bool>
Attempts to serve a file matching the request path.

Operators

operator ==(Object other) bool
The equality operator.
inherited