firstSent property
MailMessageInterface?
get
firstSent
Gets the first sent message, or null if none sent.
Implementation
MailMessageInterface? get firstSent => _sent.isEmpty ? null : _sent.first;
Gets the first sent message, or null if none sent.
MailMessageInterface? get firstSent => _sent.isEmpty ? null : _sent.first;