wasSent method
Checks if a message matching the predicate was sent.
Implementation
bool wasSent(bool Function(MailMessageInterface) predicate) {
return _sent.any(predicate);
}
Checks if a message matching the predicate was sent.
bool wasSent(bool Function(MailMessageInterface) predicate) {
return _sent.any(predicate);
}