MailAttachment class
Represents a file attachment.
Constructors
Properties
-
data
→ List<
int> ? -
final
- filename → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFilePath → bool
-
no setter
- isRawData → bool
-
no setter
- mimeType → String?
-
final
- path → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited