MailServiceProvider class

Service provider for the mail module.

Registers mail services in the container.

Implemented types

Constructors

MailServiceProvider()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isDeferred → bool
If true, the provider is deferred and only loaded when its services are requested.
no setteroverride
provides → List<Type>
The services provided by this provider.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

boot(ContainerInterface container) → Future<void>
Called after all providers are registered (for initialization).
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(ContainerInterface container) → void
Called when the provider is registered in the container.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited