from method
Sets the email sender (from address).
If not set, uses the default from address from configuration.
Implementation
@override
MailerInterface from(String address, [String? name]) {
_message.setFrom(address, name);
return this;
}
Sets the email sender (from address).
If not set, uses the default from address from configuration.
@override
MailerInterface from(String address, [String? name]) {
_message.setFrom(address, name);
return this;
}