from abstract method
Sets the email sender (from address).
If not set, uses the default from address from configuration.
Implementation
MailerInterface from(String address, [String? name]);
Sets the email sender (from address).
If not set, uses the default from address from configuration.
MailerInterface from(String address, [String? name]);