MailgunTransport class

Mailgun API transport for sending emails via Mailgun service.

Mailgun is a popular transactional email service with a simple API. This transport uses Mailgun's Messages API to send emails.

Example configuration:

final config = MailgunConfig(
  domain: 'mg.example.com',
  apiKey: 'key-xxxx',
  endpoint: 'https://api.mailgun.net',
);
final transport = MailgunTransport(config);

See: https://documentation.mailgun.com/en/latest/api-sending.html

Implemented types

Constructors

MailgunTransport(MailgunConfig _config, {Client? client})

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Gets the transport name/identifier.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Closes the HTTP client.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(MailMessageInterface message) Future<bool>
Sends an email message.
override
test() Future<bool>
Tests the transport connection.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited