PostmarkTransport class

Postmark transport for sending emails via Postmark service.

Postmark is a transactional email service focused on delivery speed and reliability. This transport uses Postmark's Send Email API.

Example configuration:

final config = PostmarkConfig(
  serverToken: 'your-server-token',
  messageStream: 'outbound',
);
final transport = PostmarkTransport(config);

See: https://postmarkapp.com/developer/api/email-api

Implemented types

Constructors

PostmarkTransport(PostmarkConfig _config, {Client? client})

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Gets the transport name/identifier.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Closes the HTTP client.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(MailMessageInterface message) Future<bool>
Sends an email message.
override
test() Future<bool>
Tests the transport connection.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited