TransportInterface class abstract interface

Interface for mail transport drivers.

Implementations handle the actual sending of emails through various services (SMTP, SES, Mailgun, etc.).

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
Gets the transport name/identifier.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(MailMessageInterface message) → Future<bool>
Sends an email message.
test() → Future<bool>
Tests the transport connection.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited