Migrator class

Constructors

Migrator(DatabaseManager manager)

Properties

hashCode int
The hash code for this object.
no setterinherited
manager DatabaseManager
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schemaBuilder SchemaBuilder
no setter

Methods

fresh() Future<void>
Drop all tables and re-run migrations.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refresh() Future<void>
Refresh the database (Reset + Up).
registerAll(List<MigrationFile> migrations) → void
reset() Future<void>
Reset all migrations.
rollback({int steps = 0}) Future<void>
Rollback the last migration operation.
status() Future<void>
toString() String
A string representation of this object.
inherited
upAll({bool step = false}) Future<void>
Run the pending migrations.

Operators

operator ==(Object other) bool
The equality operator.
inherited