SeederManager class

Manages and runs seeders.

Constructors

SeederManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(Seeder seeder) → void
registerAll(List<Seeder> seeders) → void
run(String name) Future<void>
runAll() Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited