withRelations property
List
get
withRelations
The relationships that should be eager loaded on every query.
Implementation
List<dynamic> get withRelations => [];
The relationships that should be eager loaded on every query.
List<dynamic> get withRelations => [];