RouteGroup class
Route group config object.
This class is used to group routes together and define them in a closure. It also allows you to define middleware for the group of routes.
Constructors
-
RouteGroup({required void defineRoutes(Router router), String prefix = '', List<
Middleware> middleware = const []}) - Creates a new instance of RouteGroup.
Properties
- defineRoutes → void Function(Router router)
-
The closure that defines the routes for this group.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
middleware
→ List<
Middleware> -
The middleware for this group of routes.
final
- prefix → String
-
The prefix for the routes in this group.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
Router router) → void -
Registers the routes for this group with the given
router. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited