RouteGroup constructor

RouteGroup({
  1. required void defineRoutes(
    1. Router router
    ),
  2. String prefix = '',
  3. List<Middleware> middleware = const [],
})

Creates a new instance of RouteGroup.

The prefix parameter is used to define the prefix for the routes in this group. The middleware parameter is used to define the middleware for this group of routes. The defineRoutes parameter is a closure that defines the routes for this group.

Implementation

RouteGroup({
  required this.defineRoutes,
  this.prefix = '',
  this.middleware = const [],
});