RouteGroupManager class

Handles route grouping functionality.

Constructors

RouteGroupManager(RouteRegistry _registry)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

group({required String prefix, required void routes(RouteRegistry registry), List<Middleware> middleware = const []}) → void
Groups a set of routes under a prefix and optional middleware.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited