RouteHandler class
Handles route handler wrapping and execution.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
executeHandler(
RequestHandler handler, Request req, Response res) → Future< void> - Executes a handler with proper error handling.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
wrapHandlers(
List< RequestHandler> handlers) → List<RequestHandler> - Wraps multiple handlers with exception handling.
-
wrapWithExceptionHandler(
RequestHandler handler) → RequestHandler - Wraps a route handler with exception handling.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited