scheduler library

Classes

ScheduledTask
A scheduled task that can be executed at specified intervals
SchedulerEngine
The main scheduler engine that manages scheduled tasks
SchedulerJobRegistry
Registry for managing scheduled jobs

Properties

scheduler SchedulerEngine
Global scheduler instance
final

Functions

startSchedulers({List<ScheduledTask> tasks = const [], List<JobDefinition> configJobs = const []}) → void
Bootstrap function to initialize and start the scheduler system
stopSchedulers() → void
Shutdown function to gracefully stop all scheduler activities