SessionConfig class

Configuration for session management

Constructors

SessionConfig({required String driver, required int lifetime, required bool expireOnClose, required bool encrypt, required String path, required bool secure, required bool httpOnly, required String sameSite, String? domain})
const
SessionConfig.fromMap(Map<String, dynamic> map)
factory

Properties

domain → String?
final
driver → String
final
encrypt → bool
final
expireOnClose → bool
final
hashCode → int
The hash code for this object.
no setterinherited
httpOnly → bool
final
lifetime → int
final
path → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sameSite → String
final
secure → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited