SessionValidator class
Session Data Validator Handles session data validation and expiration checks
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
initializeSessionData(
[Map< String, dynamic> initialData = const {}]) → Map<String, dynamic> - Initialize session data
-
isExpired(
Map< String, dynamic> data, Duration maxAge) → bool - Check if session data indicates expiration
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateLastAccessed(
Map< String, dynamic> data) → void - Update last accessed timestamp
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited