SocketChannel class

Represents a communication channel (namespace) in the socket system.

Channels allow you to separate concerns by grouping related events. For example, you might have a 'chat' channel and a 'notifications' channel.

Constructors

SocketChannel(String name)

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
The name of the channel (namespace).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getEntry(String event) SocketEventEntry?
Get the handler entry for a specific event.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, SocketEventHandler handler) → void
Register an event handler.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited