handshakeRequest property
The initial HTTP request that established the WebSocket connection. This contains the handshake headers, query parameters, and initial attributes.
Implementation
final Request handshakeRequest;
The initial HTTP request that established the WebSocket connection. This contains the handshake headers, query parameters, and initial attributes.
final Request handshakeRequest;