SocketConfig class

Constructors

SocketConfig({required int port, String? host, Duration? pingInterval, int? maxMessageBytes, bool shared = true})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
host String?
final
maxMessageBytes int?
final
pingInterval Duration?
final
port int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shared bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited