context property
SocketContext
get
context
The current socket context.
This is only available during the execution of an event handler.
Implementation
SocketContext get context => SocketContext.current;
The current socket context.
This is only available during the execution of an event handler.
SocketContext get context => SocketContext.current;