register method
Internal method to register the controller with the router.
Implementation
void register(SocketRouter router) {
_channel = router.channel(namespace);
init();
}
Internal method to register the controller with the router.
void register(SocketRouter router) {
_channel = router.channel(namespace);
init();
}