isSubscribed method
Check if a client is subscribed to an event.
Implementation
bool isSubscribed(String event, SocketClient client) {
return _adapter.isSubscribed(event, client);
}
Check if a client is subscribed to an event.
bool isSubscribed(String event, SocketClient client) {
return _adapter.isSubscribed(event, client);
}