sendToUsers method

void sendToUsers(
  1. List userIds,
  2. String event,
  3. dynamic data
)

Send a message to multiple specific users by User IDs.

Requires clients to be authenticated and have user IDs.

Implementation

void sendToUsers(List<dynamic> userIds, String event, dynamic data) {
  _adapter.sendToUsers(userIds, event, data);
}