SocketPacket class

Constructors

SocketPacket({required String event, dynamic data, String? id, String? namespace})
const
SocketPacket.fromMap(Map<String, dynamic> map)
factory

Properties

data → dynamic
final
event String
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
namespace String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parse(dynamic raw, {int? maxMessageBytes}) SocketPacket