LocalDisk class

Implemented types

Constructors

LocalDisk({required String basePath})

Properties

basePath String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copy(String from, String to) Future<void>
Copies the file from one path to another.
override
delete(String path) Future<void>
Deletes the file saved at the given path on the disk.
override
deleteDirectory(String path) Future<void>
Deletes a directory.
override
exists(String path) Future<bool>
Checks if the file exists at the given path.
override
get(String path) Future<List<int>>
Retrieves the bytes saved at the given path on the disk.
override
getStream(String path) Stream<List<int>>
Retrieves the file content as a stream.
override
lastModified(String path) Future<DateTime>
Returns the last modified time of the file.
override
listFiles(String directoryPath) Future<List<String>>
Lists files under the specified directory.
override
makeDirectory(String path) Future<void>
Creates a directory.
override
mimeType(String path) Future<String?>
Returns the MIME type of the file.
override
move(String from, String to) Future<void>
Moves the file from one path to another.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put(String path, List<int> bytes) Future<void>
Saves the given bytes to the given path on the disk.
override
putStream(String path, Stream<List<int>> stream) Future<void>
Saves the given stream to the given path on the disk.
override
readString(String path) Future<String>
Reads a string from a file.
override
size(String path) Future<int>
Returns the size of the file in bytes.
override
temporaryUrl(String path, DateTime expiration) Future<String>
Returns a temporary URL to the file (e.g. signed URL).
override
toString() String
A string representation of this object.
inherited
url(String path) String
Returns the full URL or public path to the file.
override
writeString(String path, String content) Future<void>
Writes a string directly to a file.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited