put method
Saves the given bytes to the given path on the disk.
Implementation
@override
Future<void> put(String path, List<int> bytes) async {
final file = _file(path);
await file.create(recursive: true);
await file.writeAsBytes(bytes);
}
Saves the given bytes to the given path on the disk.
@override
Future<void> put(String path, List<int> bytes) async {
final file = _file(path);
await file.create(recursive: true);
await file.writeAsBytes(bytes);
}