Asset class
Facade for asset helpers and storage-backed asset operations.
Use Asset.url, Asset.storeFile, and related helpers to manage
assets without resolving the underlying AssetService.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
asset(
String path, {Map< String, dynamic> ? query}) → String -
copyFile(
String from, String to, {String disk = 'public'}) → Future< void> -
css(
String path, {Map< String, dynamic> ? query}) → String -
deleteFile(
String path, {String disk = 'public'}) → Future< void> -
fileExists(
String path, {String disk = 'public'}) → Future< bool> -
fileSize(
String path, {String disk = 'public'}) → Future< int> -
generateUniqueFilename(
String originalFilename) → String -
getFileExtension(
String filename) → String -
getFileNameWithoutExtension(
String filename) → String -
image(
String path, {Map< String, dynamic> ? query}) → String -
isValidFileType(
String filename, List< String> allowedExtensions) → bool -
js(
String path, {Map< String, dynamic> ? query}) → String -
listFiles(
String directory, {String disk = 'public'}) → Future< List< String> > -
mimeType(
String path, {String disk = 'public'}) → Future< String?> -
moveFile(
String from, String to, {String disk = 'public'}) → Future< void> -
storage(
String path, {Map< String, dynamic> ? query}) → String -
storeFile(
String path, List< int> bytes, {String disk = 'public', String? filename}) → Future<String> -
storeTextFile(
String path, String content, {String disk = 'public', String? filename}) → Future< String> -
url(
String path, {Map< String, dynamic> ? query}) → String