CliServiceProvider class

A lightweight service provider for CLI-only context. Does not start servers or workers, just logging + database + migrator.

Inheritance

Constructors

CliServiceProvider()

Properties

hashCode int
The hash code for this object.
no setterinherited
isDeferred bool
If true, the provider is deferred and only loaded when its services are requested.
no setterinherited
provides List<Type>
The services provided by this provider.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

boot(ContainerInterface container) Future<void>
Called after all providers are registered (for initialization).
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(ContainerInterface container) → void
Called when the provider is registered in the container.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited