Config class

Facade for application configuration.

Use Config.get, Config.section, and related helpers to access configuration values without resolving the config service manually.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

all() → Map<String, dynamic>
get<T>(String key, [T? defaultValue]) → T?
getOrFail<T>(String key) → T
has(String key) → bool
loadFromRegistry(Map<String, Map<String, dynamic>> registry) → void
pop(String key) → void
push(String key, dynamic value) → void
reload() → void
section(String name) → Map<String, dynamic>?
set(String key, dynamic value) → void