CookieMiddleware class

Cookie Middleware

Provides convenient cookie access methods to requests and responses. Adds cookie helper methods to the request and response objects.

Inheritance

Constructors

CookieMiddleware()

Properties

handler MiddlewareHandler
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
name String
no setterinherited
priority MiddlewarePriority
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited