register method
Called when the provider is registered in the container.
Implementation
@override
void register(ContainerInterface container) {
_registerCoreBindings(container);
}
Called when the provider is registered in the container.
@override
void register(ContainerInterface container) {
_registerCoreBindings(container);
}