FileRule class
Validates that the field is an UploadedFile.
Signature: file
Examples:
Properties
-
customMessage
↔ String?
-
The error message to be returned if validation fails.
Can be overridden by the user.
getter/setter pairinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
signature
→ String
-
Returns the unique signature of the rule.
Defaults to the class name in snake_case (logic handled by registry usually, but good to have).
no setteroverride