KhademPackageMetadata class

Constructors

KhademPackageMetadata({required String version, required String sdkConstraint, required String documentation, required String releaseDate})
const

Properties

author String
no setter
documentation String
final
hashCode int
The hash code for this object.
no setterinherited
releaseDate String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sdkConstraint String
final
version String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited