PhoneRule class

Validates that a value is a valid phone number.

Checks against E.164 standard format (up to 15 digits). Allows optional leading + and sanitized separators like spaces, dashes, and parentheses.

Signature: phone

Examples:

  • phone
Inheritance

Constructors

PhoneRule()

Properties

customMessage String?
The error message to be returned if validation fails. Can be overridden by the user.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signature String
Returns the unique signature of the rule. Defaults to the class name in snake_case (logic handled by registry usually, but good to have).
no setteroverride

Methods

message(ValidationContext context) String
Returns the validation error message.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
passes(ValidationContext context) FutureOr<bool>
Validates the value using the given context.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited