register method
Called when the provider is registered in the container.
Implementation
@override
void register(ContainerInterface container) {
container.lazySingleton<QueueManager>(
(c) => QueueManager(c.resolve<ConfigInterface>()),
);
}
Called when the provider is registered in the container.
@override
void register(ContainerInterface container) {
container.lazySingleton<QueueManager>(
(c) => QueueManager(c.resolve<ConfigInterface>()),
);
}