RateLimitMiddleware class

A middleware that limits the number of requests from a single IP address within a specified time window.

Implemented types

Constructors

RateLimitMiddleware({int maxRequests = 60, Duration window = const Duration(minutes: 1)})

Properties

handler MiddlewareHandler
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
maxRequests int
final
name String
no setteroverride
priority MiddlewarePriority
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
window Duration
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited