isSubscribed static method
Check if a client is subscribed to an event.
Implementation
static bool isSubscribed(String event, SocketClient client) {
return _manager.isSubscribed(event, client);
}
Check if a client is subscribed to an event.
static bool isSubscribed(String event, SocketClient client) {
return _manager.isSubscribed(event, client);
}