sendToUser static method
Send a message to a specific user by User ID.
Requires clients to be authenticated and have a user ID.
Implementation
static void sendToUser(dynamic userId, String event, dynamic data) {
_manager.sendToUser(userId, event, data);
}