TTLFileCleanerJob class

Implemented types

Constructors

TTLFileCleanerJob({required String cachePath})

Properties

cachePath → String
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
Unique name of the job (used for identification and control).
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute() → Future<void>
Main logic that should be executed when the job runs.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited