InputValidator class

Example: 'attachments': 'nullable|array', 'attachments.*': 'file|max:5120'

Available extensions

Constructors

InputValidator(Map<String, dynamic> data, Map<String, dynamic> rules, {Map<String, String> customMessages = const {}})

Properties

customMessages → Map<String, String>
final
data → Map<String, dynamic>
final
errors → Map<String, List<String>>
final
hashCode → int
The hash code for this object.
no setterinherited
rules → Map<String, dynamic>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
passes() → Future<bool>
toString() → String
A string representation of this object.
inherited
validate() → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited