ExpressionEvaluator class

ExpressionEvaluator handles the evaluation of complex template expressions like user.name, items0, user.profile.email, etc.

Constructors

ExpressionEvaluator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

evaluate(String expression, Map<String, dynamic> context) → dynamic
Evaluates a complex expression against a context map Supports dot notation, array access with brackets and dots, and property access
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited