ArrayCast class
Cast attribute to/from Array (List<String>)
Example:
Map<String, Type> get casts => {
'roles': ArrayCast,
'tags': ArrayCast,
};
// Usage:
user.roles = ['admin', 'editor'];
print(user.roles.first); // 'admin'
- Inheritance
-
- Object
- AttributeCaster<
List< String> > - ArrayCast
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
get(
dynamic value) → List< String> ? -
Convert database value to model property value
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
set(
List< String> ? value) → dynamic -
Convert model property value to database value
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited