JsonCast class
Cast attribute to/from JSON (Map<String, dynamic>)
Example:
Map<String, Type> get casts => {
'settings': JsonCast,
'metadata': JsonCast,
};
// Usage:
user.settings = {'theme': 'dark', 'lang': 'en'};
print(user.settings['theme']); // 'dark'
- Inheritance
-
- Object
- AttributeCaster<
Map< String, dynamic> > - JsonCast
Constructors
- JsonCast()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
get(
dynamic value) → Map< String, dynamic> ? -
Convert database value to model property value
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
set(
Map< String, dynamic> ? value) → dynamic -
Convert model property value to database value
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited