Relation<Related extends KhademModel<Related> , Parent> class
abstract
- Implementers
Constructors
-
Relation(QueryBuilderInterface<
Related> query, Parent parent, )
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- parent → Parent
-
The parent model instance.
final
-
query
→ QueryBuilderInterface<
Related> -
The query builder instance.
final
-
The related model factory.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addConstraints(
) → void - Set the base constraints on the relation query.
-
addEagerConstraints(
List< KhademModel> models) → void - Set the constraints for an eager load of the relation.
-
getQuery(
) → QueryBuilderInterface< Related> - Get the query builder for the relation.
-
getRelationExistenceQuery(
QueryBuilderInterface< Related> query, QueryBuilderInterface<Parent> parentQuery, [List<String> columns = const ['*']]) → QueryBuilderInterface<Related> - Add the constraints for a relationship count query.
-
getResults(
) → Future - Get the results of the relationship.
-
initRelation(
List< KhademModel> models, String relation) → List<KhademModel> - Initialize the relation on a set of models.
-
match(
List< KhademModel> models, List<Related> results, String relation) → List<KhademModel> - Match the eagerly loaded results to their parents.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBase(
) → QueryBuilderInterface< Related> - Get the underlying query builder.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited