With class
Constructors
With (String relation , {List nested = const [] , bool paginate = false , int ? page , int ? perPage , dynamic query (QueryBuilderInterface )? })
A helper class to represent eager loading specifications in a structured way.
This class is used to define relations to be loaded with their nested relations and pagination settings.
Example usage:
const
Properties
hashCode
→ int
The hash code for this object.
no setter inherited
nested
→ List
A list of nested relations to be loaded within this relation.
final
page
→ int ?
The page number to load (if pagination is enabled).
final
paginate
→ bool
Whether to paginate the results of this relation.
final
perPage
→ int ?
The number of items per page (if pagination is enabled).
final
query
→ dynamic Function(QueryBuilderInterface ) ?
An optional custom query function to modify the query for this relation.
final
relation
→ String
The name of the relation to be loaded.
final
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
Methods
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString ()
→ String
A string representation of this object.
inherited