AuthDriver class abstract
Authentication driver interface
Drivers handle the low-level token operations for different authentication methods (JWT, Token, OAuth, etc.). They are used by guards to perform authentication operations.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
authenticate(
Map< String, dynamic> credentials, Authenticatable user) → Future<AuthResponse> - Attempts to authenticate a user with credentials
-
generateTokens(
Authenticatable user) → Future< AuthResponse> - Generates tokens for a user
-
invalidateToken(
String token) → Future< void> - Invalidates a token (single device logout)
-
invalidateTokenWithStrategy(
String token, LogoutType logoutType) → Future< void> - Invalidates tokens using a specific logout strategy
-
logoutFromAllDevices(
String token) → Future< void> - Invalidates all tokens for a user (logout from all devices)
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
refreshToken(
String refreshToken) → Future< AuthResponse> - Refreshes an access token
-
toString(
) → String -
A string representation of this object.
inherited
-
validateTokenFormat(
String token) → bool - Validates token format
-
verifyToken(
String token) → Future< Authenticatable> - Verifies an authentication token
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited