AuthRepository class abstract
Repository interface for authentication data access
This interface defines the contract for accessing user and token data in the authentication system. It follows the Repository pattern to abstract data access operations and make them testable.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cleanupExpiredTokens(
) → Future< int> - Cleans up expired tokens
-
deleteToken(
String token) → Future< int> - Deletes a token
-
deleteUserTokens(
dynamic userId, {String? guard, Map< String, dynamic> ? filter}) → Future<int> - Deletes all tokens for a user
-
findToken(
String token) → Future< Map< String, dynamic> ?> - Finds a token record
-
findTokensByUser(
dynamic userId, [String? guard]) → Future< List< Map< >String, dynamic> > - Finds all tokens for a user
-
findUserByCredentials(
Map< String, dynamic> credentials, List<String> fields, String table) → Future<Map< String, dynamic> ?> - Finds a user by credentials
-
findUserById(
dynamic id, String table, String primaryKey) → Future< Map< String, dynamic> ?> - Finds a user by ID
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
storeToken(
Map< String, dynamic> tokenData) → Future<Map< String, dynamic> > - Stores a token in the database
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited