DatabaseAuthenticatable class
Database authenticatable implementation
This class provides a standardized implementation of Authenticatable that uses provider configuration to determine field mappings. It eliminates code duplication across drivers and guards.
- Implemented types
Constructors
-
DatabaseAuthenticatable(Map<
String, dynamic> _data, {required String primaryKey, String passwordField = 'password'}) - Creates a database authenticatable instance
-
DatabaseAuthenticatable.fromProviderConfig(Map<
String, dynamic> userData, Map<String, dynamic> providerConfig) -
Factory constructor that creates instance from provider config
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAuthIdentifier(
) → dynamic -
Gets the unique identifier for the user
override
-
getAuthIdentifierName(
) → String -
Gets the name of the unique identifier column
override
-
getAuthPassword(
) → String? -
Gets the password for the user
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toAuthArray(
) → Map< String, dynamic> -
Converts the user to an array for authentication
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited