KhademAuthConfig class
Khadem implementation of AuthConfig
This class implements the AuthConfig interface using the Khadem configuration system. It provides access to authentication configuration with proper error handling.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAllProviderKeys(
) → List< String> -
Gets all available provider keys
override
-
getDefaultGuard(
) → String -
Gets the default guard name
override
-
getDefaultProvider(
) → String -
Gets the default provider key
override
-
getDriver(
String driverName) → Map< String, dynamic> -
Gets the driver configuration
override
-
getGuard(
String guardName) → Map< String, dynamic> -
Gets the guard configuration
override
-
getOrDefault<
T> (String key, T defaultValue) → T -
Gets a configuration value with a default fallback
override
-
getProvider(
String providerKey) → Map< String, dynamic> -
Gets the authentication provider configuration
override
-
getProvidersForGuard(
String guardName) → List< Map< String, dynamic> > -
Gets providers for a specific guard
override
-
hasGuard(
String guardName) → bool -
Checks if a guard exists
override
-
hasProvider(
String providerKey) → bool -
Checks if a provider exists
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited