Verifies a password against its hash
password The plain text password hash The hashed password to verify against Returns true if password matches the hash
password
hash
Future<bool> verify(String password, String hash);