WebAuthMiddleware class
Web Authentication Middleware
Middleware for protecting routes that require authentication. Uses the AuthManager with the 'web' guard for session-based authentication.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
admin(
{String redirectTo = '/login', List< String> except = const [], String guard = 'web'}) → Middleware - Factory method for admin-only middleware
-
auth(
{String redirectTo = '/login', List< String> except = const [], String guard = 'web'}) → Middleware - Factory method for basic auth middleware
-
create(
{String redirectTo = '/login', List< String> except = const [], String guard = 'web'}) → Middleware - Creates a new web authentication middleware
-
guest(
{String redirectTo = '/dashboard', List< String> except = const [], String guard = 'web'}) → Middleware - Factory method for guest-only middleware (redirects authenticated users)