many abstract method
Retrieves multiple values from the cache by their keys.
Returns a map of key-value pairs. Keys not found in the cache will not be present in the returned map.
- Parameters:
keys: A list of keys to retrieve.
Implementation
Future<Map<String, dynamic>> many(List<String> keys);