menu
khadem package
documentation
contracts.dart
CacheDriver
pull abstract method
pull abstract method
dark_mode
light_mode
pull
abstract method
Future
pull
(
String
key
)
Retrieve an item from the cache and delete it.
Parameters:
key
: The key of the item to retrieve and delete.
Returns: The value of the item, or
null
if not found.
Implementation
Future<dynamic> pull(String key);
khadem package
documentation
contracts
CacheDriver
pull abstract method
CacheDriver class