instance<T> abstract method
void
instance<T>(
- T instance
Registers an existing instance of type T as a singleton.
The provided instance is used directly for all resolutions of T.
instance: The instance to register.
Throws an exception if a binding for T already exists.
Implementation
void instance<T>(T instance);