resolveType abstract method
Resolves and returns an instance of the given type.
This is the dynamic version of resolve.
type: The type to resolve.context: Optional context key for contextual resolution.
Returns the resolved instance.
Throws an exception if no binding exists for type or if resolution fails.
Implementation
dynamic resolveType(Type type, [String? context]);