setMissingBindingHandler abstract method
Sets a handler to be called when a service is not found.
This allows for lazy loading of service providers or dynamic binding.
Implementation
void setMissingBindingHandler(void Function(Type type) handler);
Sets a handler to be called when a service is not found.
This allows for lazy loading of service providers or dynamic binding.
void setMissingBindingHandler(void Function(Type type) handler);