DatabaseResponse class
Represents a response from a database query.
data contains the response data from the query, which can be a list of
maps, a single map, or null if the query did not return any data.
insertId is the ID of the last inserted row, if the query was an insert operation.
affectedRows is the number of rows affected by the query, if the query was an update or delete operation.
Constructors
- DatabaseResponse({dynamic data, int? insertId, int? affectedRows})
Properties
- affectedRows → int?
-
final
- data → dynamic
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- insertId → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited