Dead Letter Queue interface for handling permanently failed jobs
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → Future< void> - Clear all failed jobs
-
count(
) → Future< int> - Get the total count of failed jobs
-
get(
String id) → Future< FailedJob?> - Retrieve a failed job by ID
-
getAll(
{int? limit, int? offset}) → Future< List< FailedJob> > - Get all failed jobs
-
getByDateRange(
DateTime start, DateTime end) → Future< List< FailedJob> > - Get failed jobs within a date range
-
getByType(
String jobType, {int? limit}) → Future< List< FailedJob> > - Get failed jobs filtered by type
-
getStats(
) → Future< Map< String, dynamic> > - Get failed job statistics
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
String id) → Future< void> - Remove a failed job from the DLQ
-
store(
FailedJob job) → Future< void> - Store a failed job in the DLQ
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited