getBool abstract method
Returns the value of the key as a boolean.
Accepts "true", "1" (case-insensitive) as true.
If the value is missing or invalid, returns the defaultValue.
Implementation
bool getBool(String key, {bool defaultValue = false});