Event class abstract
Base class for all application events.
Events serve as data containers that hold information related to a specific occurrence in the application.
- Implementers
Constructors
- Event()
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited