EventSubscriberInterface class abstract
Interface for classes that want to subscribe to events using handler methods.
Used to group event logic inside a single class.
- Annotations
-
- @Deprecated('Use the Subscriber interface instead')
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getEventHandlers(
) → List< EventMethod> - Returns a list of event handler definitions in this subscriber.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited