Interface for handling failed jobs and retry logic
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
exportToJson(
{int? limit}) → Future< String> - Export failed jobs to JSON
-
getReport(
) → Future< Map< String, dynamic> > - Get failed job report
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
prune(
{Duration? olderThan}) → Future< int> - Prune old failed jobs
-
recordFailure(
{required String id, required String jobType, required Map< String, dynamic> payload, required dynamic error, required int attempts, StackTrace? stackTrace, Map<String, dynamic> ? metadata}) → Future<void> - Record a job failure
-
retry(
String id) → Future< FailedJob?> - Retry a failed job (returns the job for re-dispatch)
-
retryByType(
String jobType) → Future< List< FailedJob> > - Retry all failed jobs of a specific type
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited