ICacheValidator class abstract
Interface for cache validation. Defines the contract for validating cache operations and inputs.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validateDriverName(
String name) → void - Validates a driver name. Throws CacheException if the driver name is invalid.
-
validateKey(
String key) → void - Validates a cache key. Throws CacheException if the key is invalid.
-
validateTags(
List< String> tags) → void - Validates cache tags. Throws CacheException if any tag is invalid.
-
validateTtl(
Duration ttl) → void - Validates a TTL duration. Throws CacheException if the TTL is invalid.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited