ISessionManager class abstract
Session manager interface. Defines the contract for session management operations.
- Implementers
Constructors
Properties
- driverName → String
-
Get current driver name
no setter
-
driverNames
→ List<
String> -
Get all available driver names
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cleanupExpiredSessions(
) → Future< void> - Cleanup expired sessions
-
clearSessionCookie(
HttpResponse response) → void - Clear session cookie
-
createSession(
[Map< String, dynamic> initialData = const {}]) → Future<String> - Create a new session
-
destroySession(
String sessionId) → Future< void> - Destroy session
-
flash(
String sessionId, String key, dynamic value) → Future< void> - Flash data to session
-
flashOldInput(
String sessionId, Map< String, dynamic> inputData) → Future<void> - Flash old input data to session for form repopulation
-
getFlashed(
String sessionId, String key) → Future - Get flashed data (and clear it)
-
getOldInput(
String sessionId) → Future< Map< String, dynamic> ?> - Get and clear flashed old input data
-
getSession(
String sessionId) → Future< Map< String, dynamic> ?> - Get session data
-
getSessionIdFromRequest(
HttpRequest request) → String? - Get session ID from request
-
getSessionValue(
String sessionId, String key) → Future - Get session value
-
hasValidSession(
String sessionId) → Future< bool> - Check if session exists and is valid
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
regenerateSession(
String oldSessionId) → Future< String> - Regenerate session ID
-
removeSessionValue(
String sessionId, String key) → Future< void> - Remove session value
-
setSessionCookie(
HttpResponse response, String sessionId) → void - Set session cookie
-
setSessionValue(
String sessionId, String key, dynamic value) → Future< void> - Set session value
-
switchDriver(
String driverName) → Future< void> - Switch to a different driver
-
toString(
) → String -
A string representation of this object.
inherited
-
updateSession(
String sessionId, Map< String, dynamic> newData) → Future<void> - Update session data
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited