LogHandler class abstract
Interface for log handlers.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- minimumLevel → LogLevel
-
The minimum log level this handler should process.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void -
log(
LogLevel level, String message, {Map< String, dynamic> ? context, StackTrace? stackTrace}) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited