LoggerContract class abstract
Interface for the logger system
- Implementers
Constructors
Properties
- defaultChannel → String
-
Gets the default channel
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- minimumLevel ↔ LogLevel
-
Gets the minimum log level
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addHandler(
LogHandler handler, {String channel = 'app'}) → void - Adds a log handler to a specific channel
-
close(
) → void - Closes all log handlers
-
critical(
String message, {Map< String, dynamic> ? context, StackTrace? stackTrace, String? channel}) → void - Logs a critical message
-
debug(
String message, {Map< String, dynamic> ? context, StackTrace? stackTrace, String? channel}) → void - Logs a debug message
-
error(
String message, {Map< String, dynamic> ? context, StackTrace? stackTrace, String? channel}) → void - Logs an error message
-
info(
String message, {Map< String, dynamic> ? context, StackTrace? stackTrace, String? channel}) → void - Logs an info message
-
loadFromConfig(
ConfigInterface config, {String channel = "app"}) → void - Loads logger configuration from the config system
-
log(
LogLevel level, String message, {Map< String, dynamic> ? context, StackTrace? stackTrace, String? channel}) → void - Log a message with a specific level
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setDefaultChannel(
String channel) → void - Sets the default channel for logging
-
toString(
) → String -
A string representation of this object.
inherited
-
warning(
String message, {Map< String, dynamic> ? context, StackTrace? stackTrace, String? channel}) → void - Logs a warning message
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited