QueueJobContext class
Context passed through the middleware pipeline
Constructors
-
QueueJobContext({required QueueJob job, Map<
String, dynamic> ? metadata})
Properties
- elapsed → Duration
-
Duration since job started
no setter
- error ↔ dynamic
-
getter/setter pair
- hasError → bool
-
Check if job has error
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSuccess → bool
-
Check if job completed successfully
no setter
- job → QueueJob
-
final
-
metadata
→ Map<
String, dynamic> -
final
- result ↔ dynamic
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace ↔ StackTrace?
-
getter/setter pair
- startedAt → DateTime
-
final
Methods
-
addMetadata(
String key, dynamic value) → void - Add metadata
-
getMetadata<
T> (String key) → T? - Get metadata
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited