RuleMessageParametersProvider class abstract interface

Optional contract for rules that want to provide extra localization parameters for their error messages.

Example: the in rule can provide a values parameter used by translations like Allowed values: :values.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

messageParameters(ValidationContext context) Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited