ScheduledJob class abstract
Represents a job that can be scheduled for execution at a specific time or interval.
Implement this abstract class to define your own scheduled jobs.
Example:
class CleanupJob extends ScheduledJob {
@override
String get name => 'cleanup_job';
@override
Future<void> execute() async {
// your logic here
}
}
- Implementers
Constructors
Properties
Methods
-
execute(
) → Future< void> - Main logic that should be executed when the job runs.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited