Scheduler class abstract
Scheduler interface for managing and executing scheduled tasks.
Allows scheduling tasks, stopping them, and checking their status. Intended to be implemented by classes like CronScheduler, IntervalScheduler, etc.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
schedule(
ScheduledTask task) → void -
Adds a new scheduled
taskto the scheduler. -
status(
) → List< Map< String, dynamic> > - Returns the current status of all scheduled tasks.
-
stop(
String name) → void -
Stops a running task by its unique
name. -
stopAll(
) → void - Stops all running scheduled tasks.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited