ServiceProvider class abstract

Base class for creating service providers.

A service provider registers dependencies and may execute boot logic after registration.

Implementers

Constructors

ServiceProvider()

Properties

hashCode int
The hash code for this object.
no setterinherited
isDeferred bool
If true, the provider is deferred and only loaded when its services are requested.
no setter
provides List<Type>
The services provided by this provider.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

boot(ContainerInterface container) Future<void>
Called after all providers are registered (for initialization).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(ContainerInterface container) → void
Called when the provider is registered in the container.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited