SessionDriver class abstract
Session storage driver interface. Defines the contract for session storage implementations.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cleanup(
Duration maxAge) → Future< void> - Clean up expired sessions
-
delete(
String sessionId) → Future< void> - Delete session data
-
isConnected(
) → Future< bool> - Check if driver is connected/ready
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
String sessionId) → Future< Map< String, dynamic> ?> - Retrieve session data
-
toString(
) → String -
A string representation of this object.
inherited
-
write(
String sessionId, Map< String, dynamic> data) → Future<void> - Store session data
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited