ShouldQueue class abstract

Interface for listeners that should be executed in the background queue.

Constructors

ShouldQueue()

Properties

connection String?
The name of the connection the job should be sent to.
no setter
delay int?
The number of seconds before the job should be processed.
no setter
hashCode int
The hash code for this object.
no setterinherited
queue String?
The name of the queue the job should be sent to.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited