StoppableEvent class abstract
Interface for events that can be stopped from propagating.
- Inheritance
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isPropagationStopped → bool
-
Checks if the event propagation has been stopped.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
The time when the event occurred.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
stopPropagation(
) → void - Stops the event from being processed by further listeners.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited