TaskStats class
Statistics for a scheduled task
Constructors
Properties
- averageExecutionTime → double
-
Average execution time in milliseconds
final
- failureCount → int
-
Number of times the task has failed
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastRun → DateTime?
-
When the task was last executed
final
- name → String
-
The name of the task
final
- nextRun → DateTime?
-
When the task is next scheduled to run
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → TaskStatus
-
Current status of the task
final
- successCount → int
-
Number of times the task has run successfully
final
Methods
-
copyWith(
{String? name, DateTime? lastRun, DateTime? nextRun, int? successCount, int? failureCount, double? averageExecutionTime, TaskStatus? status}) → TaskStats - Create a copy of this TaskStats with some properties changed
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited