ValidationContext class
Context object containing all information needed for validation.
Constructors
Properties
- attribute → String
-
The name of the field being validated.
final
-
data
→ Map<
String, dynamic> -
The full data object being validated.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
parameters
→ List<
String> -
The arguments passed to the validation rule (e.g. min:5 ->
'5').final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → dynamic
-
The value being validated.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited