CacheValidator class
Implementation of cache validator. Handles input validation and business rules for cache operations.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validateConfigStructure(
Map< String, dynamic> config) → void - Validates configuration map structure.
-
validateDriverName(
String name) → void -
Validates a driver name.
Throws CacheException if the driver name is invalid.
override
-
validateKey(
String key) → void -
Validates a cache key.
Throws CacheException if the key is invalid.
override
-
validateTags(
List< String> tags) → void -
Validates cache tags.
Throws CacheException if any tag is invalid.
override
-
validateTtl(
Duration ttl) → void -
Validates a TTL duration.
Throws CacheException if the TTL is invalid.
override
-
validateValueSize(
dynamic value, {int maxSize = 10 * 1024 * 1024}) → void - Validates cache value size.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited