instance property
ContainerInterface
get
instance
Gets the global container instance.
Returns the singleton container instance that can be used to register and resolve dependencies throughout the application.
Returns the global ContainerInterface instance
Implementation
static ContainerInterface get instance => _instance;