priority property
The priority of the handler.
The priority determines the order in which the event handlers are executed. The handlers with the highest priority are executed first.
Implementation
final EventPriority priority;
The priority of the handler.
The priority determines the order in which the event handlers are executed. The handlers with the highest priority are executed first.
final EventPriority priority;