addToGroup method
Adds an event to a named group groupName.
Groups allow you to organize related events and emit them together using emitGroup. If the group doesn't exist, it will be created.
groupName - The name of the group to add the event to
event - The event name to add to the group
Implementation
@override
void addToGroup(String groupName, String event) {
_eventGroups[groupName] ??= {};
_eventGroups[groupName]!.add(event);
}