LogFormatter class abstract
Interface for log message formatters. Responsible for formatting log entries into strings.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
format(
LogLevel level, String message, {Map< String, dynamic> ? context, StackTrace? stackTrace, DateTime? timestamp}) → String - Formats a log entry into a string.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited