LoggingConfiguration class
Configuration manager for the logging system. Handles loading and parsing logging configuration from the application config.
Constructors
- LoggingConfiguration(ConfigInterface _config)
Properties
-
channels
→ Map<
String, List< LogHandler> > -
Gets the configured log channels and their handlers.
no setter
- defaultChannel → String
-
Gets the default logging channel from configuration.
no setter
-
handlers
→ List<
LogHandler> -
Gets the configured log handlers (Legacy support).
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- minimumLevel → LogLevel
-
Gets the minimum log level from configuration.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
) → void - Validates the logging configuration. Throws an exception if the configuration is invalid.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited