StreamLogHandler class
A log handler that writes log entries to a Stream. Useful for real-time log monitoring or piping logs to other systems.
- Implemented types
Constructors
- StreamLogHandler({bool sync = false, LogLevel minimumLevel = LogLevel.debug})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- minimumLevel → LogLevel
-
The minimum log level this handler should process.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stream
→ Stream<
LogEntry> -
The stream of log entries.
no setter
Methods
-
close(
) → void -
override
-
log(
LogLevel level, String message, {Map< String, dynamic> ? context, StackTrace? stackTrace}) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited