ConditionalMiddleware class
Conditional middleware - only run if condition is met
- Implemented types
Constructors
- ConditionalMiddleware({required bool condition(QueueJobContext context), required QueueMiddleware middleware})
Properties
- condition → bool Function(QueueJobContext context)
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- middleware → QueueMiddleware
-
final
- name → String
-
Get middleware name for debugging
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
handle(
QueueJobContext context, Next next) → Future< void> -
Handle the job context
Call next() to continue to the next middleware or job execution
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited