DeduplicationMiddleware class
Prevents duplicate job execution within time window
- Implemented types
Constructors
- DeduplicationMiddleware({required Duration window})
Properties
Methods
-
handle(
QueueJobContext context, Next next) → Future< void> -
Handle the job context
Call next() to continue to the next middleware or job execution
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited