ErrorHandlingMiddleware class

Error handling middleware

Implemented types

Constructors

ErrorHandlingMiddleware({void onError(dynamic job, dynamic error, StackTrace stack)?, bool rethrowErrors = true})

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Get middleware name for debugging
no setteroverride
onError → void Function(dynamic job, dynamic error, StackTrace stack)?
final
rethrowErrors bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

handle(QueueJobContext context, Next next) Future<void>
Handle the job context Call next() to continue to the next middleware or job execution
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited