InMemoryPriorityQueueDriver class
In-memory priority queue driver
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
Check if empty
no setter
- pendingJobs → int
-
Get pending job count
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → void - Clear all jobs
-
getAllJobs(
) → List< PrioritizedJob> - Get all jobs sorted by priority
-
getJobById(
String id) → PrioritizedJob? - Get job by ID
-
getStatsByPriority(
) → Map< String, dynamic> - Get queue statistics by priority
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
process(
) → Future< void> - Process next highest priority job
-
push(
QueueJob job, {JobPriority priority = JobPriority.normal, Duration? delay}) → Future< void> - Push a job with priority
-
removeJobById(
String id) → bool - Remove job by ID
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited