QueueMiddlewarePipeline class
Middleware pipeline for queue jobs
Constructors
Properties
- count → int
-
Get middleware count
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
middleware
→ List<
QueueMiddleware> -
Get all middleware
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
add(
QueueMiddleware middleware) → void - Add middleware to the pipeline
-
addAt(
int index, QueueMiddleware middleware) → void - Add middleware at a specific position
-
clear(
) → void - Clear all middleware
-
execute(
QueueJobContext context) → Future< void> - Execute the pipeline
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
QueueMiddleware middleware) → void - Remove middleware
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited