QueueWorker class
Enhanced queue worker with timeout enforcement and graceful shutdown
Constructors
- QueueWorker(QueueDriver _driver, QueueWorkerConfig _config)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isRunning → bool
-
Check if worker is running
no setter
- runningJobCount → int
-
Get count of currently running jobs
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
start(
) → Future< void> - Starts the worker process
-
stop(
{bool graceful = true}) → Future< void> - Stop the worker (for background workers)
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited