QueueWorkerConfig class

Configuration for enhanced queue worker behavior.

Constructors

QueueWorkerConfig({int? maxJobs, Duration delay = const Duration(seconds: 1), Duration? timeout, bool runInBackground = false, int concurrency = 1, Duration gracefulShutdownTimeout = const Duration(seconds: 30), void onError(dynamic error, StackTrace stack)?, void onJobStart(QueueJob job)?, void onJobComplete(QueueJob job, dynamic result)?, void onJobError(QueueJob job, dynamic error, StackTrace stack)?, void onShutdown()?, FailedJobHandler? failedJobHandler})
const

Properties

concurrency int
final
delay Duration
final
failedJobHandler FailedJobHandler?
final
gracefulShutdownTimeout Duration
final
hashCode int
The hash code for this object.
no setterinherited
maxJobs int?
final
onError → void Function(dynamic error, StackTrace stack)?
final
onJobComplete → void Function(QueueJob job, dynamic result)?
final
onJobError → void Function(QueueJob job, dynamic error, StackTrace stack)?
final
onJobStart → void Function(QueueJob job)?
final
onShutdown → void Function()?
final
runInBackground bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout Duration?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited