QueueWorkerPoolStats class
Statistics and monitoring for enhanced queue operations
Constructors
Properties
- averageProcessingTime → Duration
-
no setter
- failureRate → double
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- jobsFailed ↔ int
-
getter/setter pair
- jobsProcessed ↔ int
-
getter/setter pair
- jobsRetried ↔ int
-
getter/setter pair
- jobsTimedOut ↔ int
-
getter/setter pair
- lastActivity ↔ DateTime?
-
getter/setter pair
- p50ProcessingTime → Duration
-
no setter
- p95ProcessingTime → Duration
-
no setter
- p99ProcessingTime → Duration
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startTime ↔ DateTime?
-
getter/setter pair
- throughput → double
-
no setter
- timeoutRate → double
-
no setter
- uptime → Duration
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recordJobFailed(
) → void -
recordJobProcessed(
Duration processingTime) → void -
recordJobRetried(
) → void -
recordJobTimedOut(
) → void -
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited