CookieManager class
Static helper for backward compatibility or direct usage
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
deleteCookie(
HttpResponse response, String name, {String? domain, String? path}) → void -
getAllCookies(
HttpRequest request) → Map< String, String> -
getCookie(
HttpRequest request, String name) → String? -
setCookie(
HttpResponse response, String name, String value, {String? domain, String? path, DateTime? expires, Duration? maxAge, bool httpOnly = true, bool secure = true, String? sameSite = 'lax'}) → void