HttpRequestProcessor class
Handles routing, middleware, and invoking the route handler.
Constructors
- HttpRequestProcessor({required Router router, required MiddlewarePipeline globalMiddleware, ServerStaticHandler? staticHandler})
Properties
- globalMiddleware → MiddlewarePipeline
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- router → Router
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- staticHandler → ServerStaticHandler?
-
final
Methods
-
handle(
Request req, ResponseContract res) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited