ServerStatic class
Handles static file serving configuration for the server.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- staticHandler → ServerStaticHandler?
-
no setter
Methods
-
clear(
) → void - Clears the static file handler.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serveStatic(
String path) → void - Configures static file serving from a given path.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited