LogTransport class
Log mail transport for development.
Instead of actually sending emails, logs them to the application log. Useful for testing and development.
- Implemented types
Constructors
- LogTransport(Logger _logger, {bool verbose = true})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
send(
MailMessageInterface message) → Future< bool> -
Sends an email message.
override
-
test(
) → Future< bool> -
Tests the transport connection.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited