MailEmbedded class

Represents an embedded file (inline attachment).

Constructors

MailEmbedded({required String path, required String cid, String? mimeType})
const

Properties

cid String
final
hashCode int
The hash code for this object.
no setterinherited
mimeType String?
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited