SmtpDiagnosticReport class
SMTP diagnostic report.
Constructors
- SmtpDiagnosticReport(SmtpConfig config)
Properties
- checkingHost ↔ bool
-
getter/setter pair
- checkingPort ↔ bool
-
getter/setter pair
- config → SmtpConfig
-
final
- connectionTime ↔ int
-
getter/setter pair
- error ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hostResolved ↔ bool
-
getter/setter pair
- isHealthy → bool
-
Returns true if the connection is likely to work.
no setter
- portOpen ↔ bool
-
getter/setter pair
-
resolvedAddresses
↔ List<
String> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sslSupported ↔ bool
-
getter/setter pair
- success ↔ bool
-
getter/setter pair
- summary → String
-
Returns a summary of the diagnostic.
no setter
- tlsSupported ↔ bool
-
getter/setter pair
- totalTime ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited