Interface for mail transport drivers.
Implementations handle the actual sending of emails through various services (SMTP, SES, Mailgun, etc.).
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
send(
MailMessageInterface message) → Future< bool> - Sends an email message.
-
test(
) → Future< bool> - Tests the transport connection.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited