Route class

Represents a route in the application.

Constructors

Route(String method, String path, RequestHandler handler, List<Middleware> middleware, {String? name})

Properties

handler RequestHandler
final
hashCode int
The hash code for this object.
no setterinherited
isDynamic bool
Checks if the route is dynamic (contains parameters).
no setter
isNamed bool
Checks if the route has a name
no setter
matcher RegExp
final
method String
final
middleware List<Middleware>
final
name String?
final
paramNames List<String>
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

extractParams(String path) Map<String, String>
matches(String method, String path) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited