RouteMatchResult class
Represents the result of a matched route.
This class is an Application Programming Interface (API) Object Representation (Apro) of the route matching result. It contains the matched route's RequestHandler, the extracted URL parameters, and the middleware that should be executed for this route.
Constructors
-
RouteMatchResult({required RequestHandler handler, required Map<
String, String> params, required List<Middleware> middleware})
Properties
- handler → RequestHandler
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
middleware
→ List<
Middleware> -
final
-
params
→ Map<
String, String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited