MemorySessionDriver class

Memory-based session storage implementation. Stores session data in memory (not persistent across restarts).

Implemented types

Constructors

MemorySessionDriver()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionCount int
Get the number of active sessions (for debugging/testing)
no setter

Methods

cleanup(Duration maxAge) Future<void>
Clean up expired sessions
override
clearAll() → void
Clear all sessions (for testing)
delete(String sessionId) Future<void>
Delete session data
override
isConnected() Future<bool>
Check if driver is connected/ready
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(String sessionId) Future<Map<String, dynamic>?>
Retrieve session data
override
toString() String
A string representation of this object.
inherited
write(String sessionId, Map<String, dynamic> data) Future<void>
Store session data
override

Operators

operator ==(Object other) bool
The equality operator.
inherited