SessionCookieHandler class

Session Cookie Handler Handles HTTP cookie operations for sessions

Constructors

SessionCookieHandler({String cookieName = defaultCookieName, Duration defaultMaxAge = const Duration(hours: 24), bool secure = false, bool httpOnly = true, String sameSite = 'lax', String? domain})

Properties

cookieName String
final
defaultMaxAge Duration
final
domain String?
final
hashCode int
The hash code for this object.
no setterinherited
httpOnly bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sameSite String
final
secure bool
final

Methods

clearSessionCookie(HttpResponse response) → void
Clear session cookie
getSessionIdFromRequest(HttpRequest request) String?
Extract session ID from request cookies
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setSessionCookie(HttpResponse response, String sessionId, {Duration? maxAge}) → void
Set session cookie in response
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultCookieName → const String