SocketChannel class
Represents a communication channel (namespace) in the socket system.
Channels allow you to separate concerns by grouping related events. For example, you might have a 'chat' channel and a 'notifications' channel.
Constructors
- SocketChannel(String name)
Properties
Methods
-
getEntry(
String event) → SocketEventEntry? - Get the handler entry for a specific event.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
on(
String event, SocketEventHandler handler) → void - Register an event handler.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited