set method
Sets an attribute on the handshake request context. These attributes are persistent for the duration of the connection and are copied to every message request context.
Implementation
void set(String key, dynamic value) {
handshakeRequest.setAttribute(key, value);
}