SocketRouter class
Constructors
Properties
- global → SocketChannel
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
channel(
String name) → SocketChannel - Get or create a channel by name.
-
match(
String? name) → SocketChannel? - Match a channel by name.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
on(
String event, SocketEventHandler handler) → void - Register an event handler on the global channel.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited