support library

Classes

AcceptedRule
Validates that the field is "accepted".
ActiveUrlRule
Validates that the field is a valid active URL by checking DNS records.
AfterRule
Validates that the date is after a given date.
AlphaDashRule
Validates that the field contains only alpha-numeric characters, dashes, and underscores.
AlphaNumRule
Validates that the field contains only alphabetic characters and numbers.
AlphaRule
Validates that the field contains only alphabetic characters.
ArrayRule
Validates that the field under validation is a List.
Asset
Facade for asset helpers and storage-backed asset operations.
AssetService
Asset service for managing static assets and files.
BeforeRule
Validates that the date is before a given date.
BoolRule
Validates that the field under validation is a boolean.
Cache
Facade for the cache system.
CacheMiddleware
CacheServiceProvider
Service provider for cache system. Registers all cache-related dependencies in the service container.
ChannelLogger
Helper class for channel-specific logging.
CliServiceProvider
A lightweight service provider for CLI-only context. Does not start servers or workers, just logging + database + migrator.
Config
Facade for application configuration.
ConfirmedRule
Validates that the field matches the value of {field}_confirmation.
CookieMiddleware
Cookie Middleware
CoreServiceProvider
Registers all core services of the Khadem framework, including configuration, environment, logger, router, cache, and events.
CorsMiddleware
Handles Cross-Origin Resource Sharing (CORS) headers.
CreditCardRule
Validates that the field is a valid credit card number using the Luhn algorithm.
DatabaseServiceProvider
Database service provider that handles database connections, migrations, and seeders.
DateFormatRule
Validates that the field matches the given date format.
DateHelper
DateRule
Validates that the field is a valid date string.
DB
Facade for the database system.
DifferentRule
Validates that the field is different from another field.
DigitsBetweenRule
Validates that the field is numeric and its length is between min and max.
DigitsRule
Validates that the field is numeric and has an exact length of digits.
DistinctRule
Validates that the array under validation has distinct (unique) values.
DynamicAppUrlMiddleware
Middleware to update APP_URL in the environment for each request.
EmailRule
Validates that the field is a valid email address.
EndsWithRule
Validates that the field ends with one of the given values.
Env
Facade for environment variables access.
EventServiceProvider
Service provider for registering event listeners and subscribers.
ExceptionMiddleware
A global middleware to catch and handle all uncaught exceptions.
ExistsRule
Validates that a value exists in a database table.
FileRule
Validates that the field is an UploadedFile.
HashHelper
ImageRule
Validates that the file is an image.
InArrayRule
Validates that the field's value exists in another field's array.
InRule
Validates that the field is contained in the given list of values.
IntRule
Validates that the field under validation is an integer.
IpRule
Validates that the field is a valid IP address (IPv4 or IPv6).
Ipv4Rule
Validates that the field is a valid IPv4 address.
Ipv6Rule
Validates that the field is a valid IPv6 address.
JsonRule
Validates that a value is a valid JSON string.
KhademPackageMetadata
KhademPackageMetadataLoader
ListRule
Validates that the field under validation is a List. Alias for ArrayRule.
Log
Facade for application logging.
LoggingMiddleware
MacAddressRule
Validates that the field is a valid MAC address.
MapRule
Validates that the field under validation is a Map.
MaxFileSizeRule
Validates that the file size is less than or equal to maxSize (in kilobytes).
MaxItemsRule
Validates that the array has at most maxCount items.
MaxRule
Validates that the field is at most max.
MimesRule
Validates that the file matches one of the given MIME types or extensions.
MinFileSizeRule
Validates that the file size is greater than or equal to minSize (in kilobytes).
MinItemsRule
Validates that the array has at least minCount items.
MinRule
Validates that the field is at least min.
NotInArrayRule
Validates that the field's value does not exist in another field's array.
NullableRule
Indicates that the field under validation may be null.
NumericRule
Validates that the field under validation is numeric.
PasswordRule
Validates that the field is a strong password.
PhoneRule
Validates that a value is a valid phone number.
ProhibitedIfRule
Validates that the field must be missing or empty if another field is equal to a value.
ProhibitedRule
Validates that the field must be missing or empty.
QueueServiceProvider
Registers the QueueManager which is responsible for initializing and managing the queue system.
RateLimitMiddleware
A middleware that limits the number of requests from a single IP address within a specified time window.
RegexRule
Validates that the field matches the given regex pattern.
RequiredIfRule
Validates that the field is required if another field is equal to a value.
RequiredRule
Validates that the field under validation is present and not empty.
SameRule
Validates that the field is the same as another field.
SecurityHeadersMiddleware
Adds common security headers to responses.
SessionMiddleware
Session Middleware
SetLocaleMiddleware
Socket
Facade for the Socket system.
SometimesRule
Indicates that the field under validation is optional and may not be present in the input data.
StartsWithRule
Validates that the field starts with one of the given values.
Storage
Facade for the storage system.
StringRule
Validates that the field under validation is a string.
SubsetRule
Validates that all items in the array field are present in the given allowed list.
TTLFileCleanerJob
UniqueRule
Validates that a value is unique in a database table.
UrlRule
Validates that the field is a valid URL.
UrlService
Provides methods for generating URLs, assets, and routes.
UuidRule
Validates that a value is a valid UUID (Universal Unique Identifier).

Functions

app<T>([String? context]) → T
Resolves a service from the container.
jsonSafe(dynamic value) → dynamic
resolve<T>([String? context]) → T
Alias for app to resolve a service.

Exceptions / Errors

BadRequestException
Exception thrown when a request contains invalid data.
CacheException
CircularDependencyException
Exception thrown when a circular dependency is detected in the container.
ConfigException
Exception thrown when configuration operations fail.
DatabaseException
Exception class for database errors
ForbiddenException
Exception thrown when a user attempts to access a forbidden resource.
MiddlewareNotFoundException
Exception thrown when a named middleware is not found.
MissingRequestContextException
MissingResponseContextException
MissingServerContextException
NotFoundException
Exception thrown when a requested resource is not found.
PayloadTooLargeException
QueueException
ServiceNotFoundException
Exception thrown when a service is not found in the container.
StorageException
Exception thrown when storage operations fail
TooManyRequestsException
Exception thrown when a request exceeds rate limits.
UnauthorizedException
Exception thrown when a user is not authorized to access a resource.
ValidationException