CacheMiddleware class
- Implemented types
Constructors
- CacheMiddleware({Duration duration = const Duration(seconds: 10)})
Properties
- duration → Duration
-
final
- handler → MiddlewareHandler
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
no setteroverride
- priority → MiddlewarePriority
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
handle(
Request req, ResponseContract res, NextFunction next) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited