Env class
Facade for environment variables access.
Shortcuts for Env operations such as Env.get, Env.set and
type-safe helpers. This facade delegates to the global EnvSystem.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
loadedFiles
→ List<
String> -
no setter
Static Methods
-
all(
) → Map< String, String> -
clear(
) → void -
get(
String key) → String? -
getBool(
String key, {bool defaultValue = false}) → bool -
getDouble(
String key, {double defaultValue = 0.0}) → double -
getInt(
String key, {int defaultValue = 0}) → int -
getList(
String key, {String separator = ',', List< String> defaultValue = const []}) → List<String> -
getOrDefault(
String key, String defaultValue) → String -
getOrFail(
String key) → String -
has(
String key) → bool -
loadFromFile(
String path) → void -
set(
String key, String value) → void -
validateRequired(
List< String> requiredKeys) → List<String>