ExistsRule class

Validates that a value exists in a database table.

Signature: exists:table,column,extraCol,extraVal...

Examples:

  • exists:states,code - Value must exist in states table, code column.
  • exists:users,email,role,admin - Value must exist in users table where email=value AND role=admin.
Inheritance

Constructors

ExistsRule([String? _table, String? _column])

Properties

customMessage String?
The error message to be returned if validation fails. Can be overridden by the user.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signature String
Returns the unique signature of the rule. Defaults to the class name in snake_case (logic handled by registry usually, but good to have).
no setteroverride

Methods

message(ValidationContext context) String
Returns the validation error message.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
passes(ValidationContext context) FutureOr<bool>
Validates the value using the given context.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited