QueueServiceProvider class

Registers the QueueManager which is responsible for initializing and managing the queue system.

The QueueManager is initialized with the configuration from the ConfigSystem and is registered as a singleton.

Inheritance

Constructors

QueueServiceProvider()

Properties

hashCode int
The hash code for this object.
no setterinherited
isDeferred bool
If true, the provider is deferred and only loaded when its services are requested.
no setteroverride
provides List<Type>
The services provided by this provider.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

boot(ContainerInterface container) Future<void>
Initializes the QueueManager by calling its init method.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(ContainerInterface container) → void
Called when the provider is registered in the container.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited