SessionMiddleware class

Session Middleware

Automatically manages session lifecycle for HTTP requests. Creates, retrieves, and manages session data throughout the request lifecycle.

Inheritance

Constructors

SessionMiddleware({SessionManager? sessionManager})

Properties

handler MiddlewareHandler
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
name String
no setterinherited
priority MiddlewarePriority
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionManager SessionManager
Gets the current session manager instance
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited