Storage class

Facade for the storage system.

Provides convenient static access to storage operations (put/get/copy/etc.) and a short-hand to the default or named disks. Use Storage.put(...), Storage.disk('s3'), or Storage.temporaryUrl(...) from anywhere.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

copy(String from, String to) Future<void>
delete(String path) Future<void>
deleteDirectory(String path) Future<void>
disk([String? name]) StorageDisk
Returns a disk instance by name or uses the default.
exists(String path) Future<bool>
get(String path) Future<List<int>>
getStream(String path) Stream<List<int>>
lastModified(String path) Future<DateTime>
listFiles(String directoryPath) Future<List<String>>
makeDirectory(String path) Future<void>
mimeType(String path) Future<String?>
move(String from, String to) Future<void>
put(String path, List<int> bytes) Future<void>
putStream(String path, Stream<List<int>> stream) Future<void>
readString(String path) Future<String>
size(String path) Future<int>
temporaryUrl(String path, DateTime expiration) Future<String>
url(String path) String
writeString(String path, String content) Future<void>