ViewRenderer class
Constructors
- ViewRenderer({String viewsDirectory = 'resources/views', bool autoEscape = true})
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- viewsDirectory → String
-
final
Methods
-
evaluateExpression(
String expression, Map< String, dynamic> context) → dynamic - Public access to expression evaluator for testing
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
String viewName, {Map< String, dynamic> context = const {}, bool escapeOutput = true}) → Future<String> -
renderUnsafe(
String viewName, {Map< String, dynamic> context = const {}}) → Future<String> - Renders a view without escaping (use with caution!)
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → ViewRenderer
-
final